@@ -22,19 +22,17 @@
 #
 #
 
-# pylint: disable=superfluous-parens,missing-docstring,line-too-long
-# pylint: disable=wrong-import-order,invalid-name,unused-argument
 
 import sys
 import yaml
 import xmlrpc.client
 
 # configuration
-USER = 'neil.williams'
-TOKEN = ''
-QUERY = 'testing-myjobs'
-QUERY_USER = 'neil.williams'
-HOSTNAME = 'localhost'
+USER = "neil.williams"
+TOKEN = ""
+QUERY = "testing-myjobs"
+QUERY_USER = "neil.williams"
+HOSTNAME = "localhost"
 # end configuration
 
 SUBMITTED = 0
@@ -45,38 +43,44 @@ CANCELED = 4
 CANCELING = 5
 
 STATUS_CHOICES = (
-    (SUBMITTED, 'Submitted'),
-    (RUNNING, 'Running'),
-    (COMPLETE, 'Complete'),
-    (INCOMPLETE, 'Incomplete'),
-    (CANCELED, 'Canceled'),
-    (CANCELING, 'Canceling'),
+    (SUBMITTED, "Submitted"),
+    (RUNNING, "Running"),
+    (COMPLETE, "Complete"),
+    (INCOMPLETE, "Incomplete"),
+    (CANCELED, "Canceled"),
+    (CANCELING, "Canceling"),
 )
 
 
 # main_function
 def main(args):
     # change https to http when testing with localhost
-    connection = xmlrpc.client.ServerProxy("https://%s:%s@%s/RPC2" % (USER, TOKEN, HOSTNAME))
+    connection = xmlrpc.client.ServerProxy(
+        "https://%s:%s@%s/RPC2" % (USER, TOKEN, HOSTNAME)
+    )
     data = connection.results.run_query(QUERY, 20, QUERY_USER)
     if not data:
         return 0
     print("Job, Type, Message, Time")
     for result in data:
-        job_lava = yaml.safe_load(connection.results.get_testcase_results_yaml(result['id'], 'lava', 'job'))[0]
-        job_id = job_lava['job']
-        logged = job_lava['logged']
-        if result['status'] == INCOMPLETE:
-            error_type = job_lava['metadata']['error_type']
-            msg = job_lava['metadata']['error_msg']
+        job_lava = yaml.safe_load(
+            connection.results.get_testcase_results_yaml(result["id"], "lava", "job")
+        )[0]
+        job_id = job_lava["job"]
+        logged = job_lava["logged"]
+        if result["status"] == INCOMPLETE:
+            error_type = job_lava["metadata"]["error_type"]
+            msg = job_lava["metadata"]["error_msg"]
             print("%s, '%s', '%s', '%s'" % (job_id, error_type, msg, logged))
             continue
-        elif result['status'] == COMPLETE:
+        elif result["status"] == COMPLETE:
             continue
-        print("[%s] %s" % (job_lava['job'], STATUS_CHOICES[int(result['status'])][1]))
+        print("[%s] %s" % (job_lava["job"], STATUS_CHOICES[int(result["status"])][1]))
     return 0
+
+
 # end main_function
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
