@@ -5,13 +5,12 @@ set -e
 [ -n "$1" ] && exec "$@"
 
 # Set default variables
-LOGGER_URL=${LOGGER_URL:-tcp://localhost:5555}
+URL=${URL:-http://localhost/}
 LOGLEVEL=${LOGLEVEL:-DEBUG}
 LOGFILE=${LOGFILE:--}
-MASTER_URL=${MASTER_URL:-tcp://localhost:5556}
 
 # Import variables
-[ -e /etc/lava-dispatcher/lava-slave ] && . /etc/lava-dispatcher/lava-slave
+[ -e /etc/lava-dispatcher/lava-worker ] && . /etc/lava-dispatcher/lava-worker
 
 for f in $(find /root/entrypoint.d/ -type f); do
     case "$f" in
@@ -25,4 +24,4 @@ for f in $(find /root/entrypoint.d/ -type f); do
     esac
 done
 
-exec /usr/bin/lava-slave --level "$LOGLEVEL" --log-file "$LOGFILE" --master "$MASTER_URL" --socket-addr "$LOGGER_URL" $IPV6 $SOCKS_PROXY $ENCRYPT $MASTER_CERT $SLAVE_CERT $DISPATCHER_HOSTNAME
+exec /usr/bin/lava-worker --level "$LOGLEVEL" --log-file "$LOGFILE" --url "$URL" $TOKEN $WORKER_NAME $WS_URL $HTTP_TIMEOUT
