@@ -8,10 +8,10 @@ set -e
 # Variables #
 #############
 GUNICORN_PID=0
-LAVA_COORDINATOR=0
-LAVA_LOGS_PID=0
-LAVA_MASTER_PID=0
+LAVA_CELERY_WORKER_PID=0
+LAVA_COORDINATOR_PID=0
 LAVA_PUBLISHER_PID=0
+LAVA_SCHEDULER_PID=0
 
 
 ##################
@@ -20,28 +20,28 @@ LAVA_PUBLISHER_PID=0
 handler() {
     tail_pid="${!}"
     echo "Killing:"
+    echo "* lava-celery-worker \$$LAVA_CELERY_WORKER_PID"
+    [ "$LAVA_CELERY_WORKER_PID" != "0" ] && kill $LAVA_CELERY_WORKER_PID
     echo "* lava-coordinator \$$LAVA_COORDINATOR_PID"
     [ "$LAVA_COORDINATOR_PID" != "0" ] && kill $LAVA_COORDINATOR_PID
-    echo "* lava-logs \$$LAVA_LOGS_PID"
-    [ "$LAVA_LOGS_PID" != "0" ] && kill $LAVA_LOGS_PID
-    echo "* lava-master \$$LAVA_MASTER_PID"
-    [ "$LAVA_MASTER_PID" != "0" ] && kill $LAVA_MASTER_PID
     echo "* lava-publisher \$$LAVA_PUBLISHER_PID"
     [ "$LAVA_PUBLISHER_PID" != "0" ] && kill $LAVA_PUBLISHER_PID
+    echo "* lava-scheduler \$$LAVA_SCHEDULER_PID"
+    [ "$LAVA_SCHEDULER_PID" != "0" ] && kill $LAVA_SCHEDULER_PID
     echo "* gunicorn \$$GUNICORN_PID"
     [ "$GUNICORN_PID" != "0" ] && kill $GUNICORN_PID
     echo "* apache2"
     apache2ctl stop
 
     echo "Waiting for:"
+    echo "* lava-celery-worker"
+    [ "$LAVA_CELERY_WORKER_PID" != "0" ] && wait $LAVA_CELERY_WORKER_PID || true
     echo "* lava-coordinator"
     [ "$LAVA_COORDINATOR_PID" != "0" ] && wait $LAVA_COORDINATOR_PID || true
-    echo "* lava-logs"
-    [ "$LAVA_LOGS_PID" != "0" ] && wait $LAVA_LOGS_PID || true
-    echo "* lava-master"
-    [ "$LAVA_MASTER_PID" != "0" ] && wait $LAVA_MASTER_PID || true
     echo "* lava-publisher"
     [ "$LAVA_PUBLISHER_PID" != "0" ] && wait $LAVA_PUBLISHER_PID || true
+    echo "* lava-scheduler"
+    [ "$LAVA_SCHEDULER_PID" != "0" ] && wait $LAVA_SCHEDULER_PID || true
     echo "* gunicorn"
     [ "$GUNICORN_PID" != "0" ] && wait $GUNICORN_PID || true
 
@@ -87,6 +87,24 @@ start_apache2() {
 }
 
 
+start_lava_celery_worker() {
+    USER="lavaserver"
+    GROUP="lavaserver"
+    LOGLEVEL="INFO"
+    LOGFILE="/var/log/lava-server/lava-celery-worker.log"
+    CONCURRENCY=""
+    AUTOSCALE=""
+    ARGS=""
+    [ -e /etc/default/lava-celery-worker ] && . /etc/default/lava-celery-worker
+    [ -e /etc/lava-server/lava-celery-worker ] && . /etc/lava-server/lava-celery-worker
+    if [ "$CAN_EXEC" = "1" ]; then
+        exec /usr/bin/python3 -m celery -A lava_server worker --uid $USER --gid $GROUP --loglevel $LOGLEVEL $CONCURRENCY $AUTOSCALE $ARGS
+    else
+        setsid /usr/bin/python3 -m celery -A lava_server worker --uid $USER --gid $GROUP --loglevel $LOGLEVEL --logfile $LOGFILE $CONCURRENCY $AUTOSCALE $ARGS &
+        LAVA_CELERY_WORKER_PID=$!
+    fi
+}
+
 start_lava_coordinator() {
     LOGLEVEL="DEBUG"
     LOGFILE="/var/log/lava-coordinator.log"
@@ -95,57 +113,52 @@ start_lava_coordinator() {
     if [ "$CAN_EXEC" = "1" ]; then
         exec /usr/bin/lava-coordinator --logfile - --loglevel "$LOGLEVEL"
     else
-        /usr/bin/lava-coordinator --logfile "$LOGFILE" --loglevel "$LOGLEVEL" &
+        setsid /usr/bin/lava-coordinator --logfile "$LOGFILE" --loglevel "$LOGLEVEL" &
         LAVA_COORDINATOR_PID=$!
     fi
 }
 
 
-start_lava_logs() {
-    LOGLEVEL=DEBUG
-    [ -e /etc/default/lava-logs ] && . /etc/default/lava-logs
-    [ -e /etc/lava-server/lava-logs ] && . /etc/lava-server/lava-logs
-    if [ "$CAN_EXEC" = "1" ]; then
-        exec /usr/bin/lava-server manage lava-logs --log-file - --level "$LOGLEVEL" $SOCKET $MASTER_SOCKET $IPV6 $ENCRYPT $MASTER_CERT $SLAVES_CERTS
-    else
-        /usr/bin/lava-server manage lava-logs --level "$LOGLEVEL" $SOCKET $MASTER_SOCKET $IPV6 $ENCRYPT $MASTER_CERT $SLAVES_CERTS &
-        LAVA_LOGS_PID=$!
-    fi
-}
-
-
-start_lava_master() {
-    LOGLEVEL=DEBUG
-    [ -e /etc/default/lava-master ] && . /etc/default/lava-master
-    [ -e /etc/lava-server/lava-master ] && . /etc/lava-server/lava-master
-    if [ "$CAN_EXEC" = "1" ]; then
-        exec /usr/bin/lava-server manage lava-master --log-file - --level "$LOGLEVEL" $MASTER_SOCKET $IPV6 $ENCRYPT $MASTER_CERT $SLAVES_CERTS $EVENT_URL
-    else
-        /usr/bin/lava-server manage lava-master --level "$LOGLEVEL" $MASTER_SOCKET $IPV6 $ENCRYPT $MASTER_CERT $SLAVES_CERTS $EVENT_URL &
-        LAVA_MASTER_PID=$!
-    fi
-}
-
-
 start_lava_publisher() {
+    LOGLEVEL="DEBUG"
+    HOST="*"
+    PORT=8001
+    [ -e /etc/default/lava-publisher ] && . /etc/default/lava-publisher
+    [ -e /etc/lava-server/lava-publisher ] && . /etc/lava-server/lava-publisher
     if [ "$CAN_EXEC" = "1" ]; then
-        exec /usr/bin/lava-server manage lava-publisher --log-file -
+        exec /usr/bin/lava-server manage lava-publisher --log-file - --level "$LOGLEVEL" --host "$HOST" --port "$PORT"
     else
-        /usr/bin/lava-server manage lava-publisher &
+        setsid /usr/bin/lava-server manage lava-publisher --level "$LOGLEVEL" --host "$HOST" --port "$PORT" &
         LAVA_PUBLISHER_PID=$!
     fi
 }
 
+
+start_lava_scheduler() {
+    LOGLEVEL="DEBUG"
+    [ -e /etc/default/lava-scheduler ] && . /etc/default/lava-scheduler
+    [ -e /etc/lava-server/lava-scheduler ] && . /etc/lava-server/lava-scheduler
+    if [ "$CAN_EXEC" = "1" ]; then
+        exec /usr/bin/lava-server manage lava-scheduler --log-file - --level "$LOGLEVEL" $EVENT_URL $IPV6
+    else
+        setsid /usr/bin/lava-server manage lava-scheduler --level "$LOGLEVEL" $EVENT_URL $IPV6 &
+        LAVA_SCHEDULER_PID=$!
+    fi
+}
+
+
 start_lava_server_gunicorn() {
     LOGLEVEL="DEBUG"
+    TIMEOUT=""
+    WORKER_CLASS="eventlet"
     WORKERS="4"
     LOGFILE="/var/log/lava-server/gunicorn.log"
     [ -e /etc/default/lava-server-gunicorn ] && . /etc/default/lava-server-gunicorn
     [ -e /etc/lava-server/lava-server-gunicorn ] && . /etc/lava-server/lava-server-gunicorn
     if [ "$CAN_EXEC" = "1" ]; then
-        exec /usr/bin/gunicorn3 lava_server.wsgi --log-level "$LOGLEVEL" --log-file - -u lavaserver -g lavaserver --workers "$WORKERS" --worker-tmp-dir /dev/shm $RELOAD $BIND
+        exec /usr/bin/gunicorn3 lava_server.wsgi --log-level "$LOGLEVEL" --log-file - -u lavaserver -g lavaserver --worker-class "$WORKER_CLASS" --workers "$WORKERS" --worker-tmp-dir /dev/shm $RELOAD $BIND $TIMEOUT
     else
-        /usr/bin/gunicorn3 lava_server.wsgi --log-level "$LOGLEVEL" --log-file "$LOGFILE" -u lavaserver -g lavaserver --workers "$WORKERS" --worker-tmp-dir /dev/shm $RELOAD $BIND &
+        setsid /usr/bin/gunicorn3 lava_server.wsgi --log-level "$LOGLEVEL" --log-file "$LOGFILE" -u lavaserver -g lavaserver --worker-class "$WORKER_CLASS" --workers "$WORKERS" --worker-tmp-dir /dev/shm $RELOAD $BIND $TIMEOUT &
         GUNICORN_PID=$!
     fi
 }
@@ -159,23 +172,24 @@ start_lava_server_gunicorn() {
 trap 'handler' INT QUIT TERM
 
 # List of services to start
-SERVICES=${SERVICES-"apache2 lava-coordinator lava-logs lava-master lava-publisher gunicorn postgresql"}
+# By default lava-celery-worker is not started because no broker is included
+SERVICES=${SERVICES-"apache2 lava-coordinator lava-publisher lava-scheduler gunicorn postgresql"}
 echo "$SERVICES" | grep -q apache2 && APACHE2=1 || APACHE2=0
+echo "$SERVICES" | grep -q lava-celery-worker && LAVA_CELERY_WORKER=1 || LAVA_CELERY_WORKER=0
 echo "$SERVICES" | grep -q lava-coordinator && LAVA_COORDINATOR=1 || LAVA_COORDINATOR=0
-echo "$SERVICES" | grep -q lava-logs && LAVA_LOGS=1 || LAVA_LOGS=0
-echo "$SERVICES" | grep -q lava-master && LAVA_MASTER=1 || LAVA_MASTER=0
 echo "$SERVICES" | grep -q lava-publisher && LAVA_PUBLISHER=1 || LAVA_PUBLISHER=0
+echo "$SERVICES" | grep -q lava-scheduler && LAVA_SCHEDULER=1 || LAVA_SCHEDULER=0
 echo "$SERVICES" | grep -q gunicorn && GUNICORN=1 || GUNICORN=0
 echo "$SERVICES" | grep -q postgresql && POSTGRESQL=1 || POSTGRESQL=0
 
 # Is the database needed?
-NEED_DB=$((LAVA_LOGS+LAVA_MASTER+GUNICORN+POSTGRESQL))
-# Migrate if LAVA_DB_MIGRATE is undefined and lava-master is running in this
+NEED_DB=$((LAVA_SCHEDULER+GUNICORN+POSTGRESQL))
+# Migrate if LAVA_DB_MIGRATE is undefined and lava-scheduler is running in this
 # container.
-[ "$LAVA_MASTER" = "1" ] && MIGRATE_DEFAULT="yes" || MIGRATE_DEFAULT="no"
+[ "$LAVA_SCHEDULER" = "1" ] && MIGRATE_DEFAULT="yes" || MIGRATE_DEFAULT="no"
 LAVA_DB_MIGRATE=${LAVA_DB_MIGRATE:-$MIGRATE_DEFAULT}
 # Should we use "exec"?
-CAN_EXEC=$((APACHE2+LAVA_LOGS+LAVA_MASTER+LAVA_PUBLISHER+GUNICORN+POSTGRESQL))
+CAN_EXEC=$((APACHE2+LAVA_CELERY_WORKER+LAVA_COORDINATOR+LAVA_PUBLISHER+LAVA_SCHEDULER+GUNICORN+POSTGRESQL))
 # Should we check for file owners?
 LAVA_CHECK_OWNERS=${LAVA_CHECK_OWNERS:-1}
 
@@ -265,6 +279,15 @@ then
     echo
 fi
 
+if [ "$LAVA_CELERY_WORKER" = "1" ]
+then
+    echo "Starting lava-celery-worker"
+    start_lava_celery_worker
+    echo "done"
+    echo
+fi
+
+
 if [ "$LAVA_COORDINATOR" = "1" ]
 then
     echo "Starting lava-coordinator"
@@ -273,24 +296,6 @@ then
     echo
 fi
 
-if [ "$LAVA_LOGS" = "1" ]
-then
-    echo "Checking file permissions"
-    if [ "$LAVA_CHECK_OWNERS" = "1" ]
-    then
-        check_owners
-        echo "done"
-    else
-        echo "skipped"
-    fi
-    echo
-    echo "Starting lava-logs"
-    start_lava_logs
-    echo "done"
-    echo
-fi
-
-
 if [ "$LAVA_PUBLISHER" = "1" ]
 then
     echo "Starting lava-publisher"
@@ -299,19 +304,20 @@ then
     echo
 fi
 
-if [ "$LAVA_MASTER" = "1" ]
+if [ "$LAVA_SCHEDULER" = "1" ]
 then
-    echo "Starting lava-master"
-    start_lava_master
+    echo "Starting lava-scheduler"
+    start_lava_scheduler
     echo "done"
     echo
 fi
 
+
 ################
 # Wait forever #
 ################
 cd /var/log/lava-server
 while true
 do
-  tail -F django.log gunicorn.log lava-logs.log lava-master.log lava-publisher.log /var/log/lava-coordinator.log /var/log/apache2/lava-server.log & wait ${!}
+  tail -F django.log gunicorn.log lava-celery-worker.log lava-publisher.log lava-scheduler.log /var/log/lava-coordinator.log /var/log/apache2/lava-server.log & wait ${!}
 done
