@@ -77,7 +77,7 @@ class JobError(LAVAError):
 
 class LAVABug(LAVAError):
     """
-    An error that is raised when an un-expected error is catched. Only happen
+    An error that is raised when an un-expected error is caught. Only happen
     when a bug is encountered.
     """
 
@@ -112,7 +112,7 @@ class LAVATimeoutError(LAVAError):
 
 class MultinodeProtocolTimeoutError(LAVAError):
     error_help = (
-        "MultinodeProtocolTimeoutError: Multinode wait/sync call " "has timed out."
+        "MultinodeProtocolTimeoutError: Multinode wait/sync call has timed out."
     )
     error_type = "MultinodeTimeout"
 
