@@ -29,6 +29,7 @@ from voluptuous import (
     In,
     Invalid,
     Length,
+    Match,
     MultipleInvalid,
     NotIn,
     Optional,
@@ -244,7 +245,7 @@ def check_multinode_or_device_type(data):
     multinode = data.get("protocols", {}).get("lava-multinode")
 
     if device_type and multinode:
-        raise Invalid('"device_type" shoud not be used with multinode')
+        raise Invalid('"device_type" should not be used with multinode')
     if not device_type and not multinode:
         raise Invalid('"device_type" or multinode should be defined')
 
@@ -254,7 +255,7 @@ def check_multinode_or_environment(data):
     multinode = data.get("protocols", {}).get("lava-multinode")
 
     if environment and multinode:
-        raise Invalid('"environment" shoud not be used with multinode')
+        raise Invalid('"environment" should not be used with multinode')
 
 
 def check_multinode_roles(data):
@@ -335,6 +336,7 @@ def job(extra_context_variables=[]):
                                 ),
                                 Optional("tags"): [str],
                                 Optional("environment"): dict,
+                                Optional("essential"): bool,
                                 Optional("timeout"): timeout(),
                             },
                             {
@@ -342,6 +344,7 @@ def job(extra_context_variables=[]):
                                 Required("count"): Range(min=0),
                                 Required("expect_role"): str,
                                 Required("host_role"): str,
+                                Optional("essential"): bool,
                                 Optional("request"): str,
                                 Optional("tags"): [str],
                                 Optional("timeout"): timeout(),
@@ -369,3 +372,13 @@ def job(extra_context_variables=[]):
         },
         extra_checks,
     )
+
+
+docker_image_format = Match(
+    "^[a-z0-9]+[a-z0-9._/-]*[a-z0-9]+(:[a-zA-Z0-9_]+[a-zA-Z0-9._-]*)?$",
+    msg="Invalid docker image name",
+)
+
+
+def docker(image_key="image"):
+    return {Required(image_key): docker_image_format, Optional("local"): bool}
