@@ -23,17 +23,21 @@
 from voluptuous import Msg, Optional, Required
 
 from lava_common.schemas import boot
+from lava_common.schemas import docker
 
 
 def schema():
     base = {
         Required("method"): Msg("fvp", "'method' should be 'fvp'"),
+        Optional("use_telnet"): bool,
         Required("console_string"): str,
         Required("image"): str,
         Optional("license_variable"): str,
         Optional("version_string"): str,
         Required("arguments"): [str],
         Required("prompts"): boot.prompts(),
-        Required("docker"): {Required("name"): str, Optional("local"): bool},
+        Required("docker"): docker("name"),
+        Optional("transfer_overlay"): boot.transfer_overlay(),
+        Optional("auto_login"): boot.auto_login(),
     }
     return {**boot.schema(), **base}
