@@ -20,14 +20,16 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from voluptuous import Any, Msg, Required
+from voluptuous import Any, Msg, Optional, Required
 
 from lava_common.schemas import boot
+from lava_common.schemas import docker
 
 
 def schema():
     base = {
         Required("method"): Msg("uuu", "'method' should be 'uuu'"),
         Required("commands"): Any(str, [{str: str}]),
+        Optional("docker"): docker(),
     }
     return {**boot.schema(), **base}
