@@ -28,6 +28,6 @@ from lava_common.schemas import deploy
 def schema():
     base = {
         Required("to"): "u-boot-ums",
-        Required("image"): {**deploy.url(), Optional("root_partition"): Range(min=0)},
+        Required("image"): deploy.url({Optional("root_partition"): Range(min=0)}),
     }
     return {**deploy.schema(), **base}
