@@ -49,6 +49,14 @@ def schema():
                     Optional("params"): dict,
                     **common,
                 },
+                {
+                    Required("repository"): str,
+                    Required("from"): "url",
+                    Required("compression"): str,
+                    Optional("parameters"): dict,
+                    Optional("params"): dict,
+                    **common,
+                },
                 {
                     Required("repository"): {
                         Required("metadata"): {
