@@ -18,17 +18,11 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from voluptuous import Optional, Required
+from voluptuous import Required
 
 from lava_common.schemas.test.definition import schema as base
+from lava_common.schemas import docker
 
 
 def schema():
-    docker = {
-        Required("docker"): {
-            Required("image"): str,
-            Optional("wait"): {Optional("device"): bool},
-        }
-    }
-
-    return {**base(), **docker}
+    return {**base(), Required("docker"): docker()}
