@@ -35,7 +35,7 @@ class CMSIS(Boot):
 
     @classmethod
     def action(cls):
-        return BootCMSIS()
+        return BootCMSISRetry()
 
     @classmethod
     def accepts(cls, device, parameters):
@@ -63,17 +63,6 @@ class CMSIS(Boot):
         return True, "accepted"
 
 
-class BootCMSIS(RetryAction):
-
-    name = "boot-cmsis"
-    description = "boot cmsis usb image"
-    summary = "boot cmsis usb image"
-
-    def populate(self, parameters):
-        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
-        self.pipeline.add_action(BootCMSISRetry())
-
-
 class BootCMSISRetry(RetryAction):
 
     name = "boot-cmsis-retry"
