@@ -24,7 +24,7 @@ import time
 from lava_common.exceptions import JobError
 from lava_dispatcher.action import Pipeline, Action
 from lava_dispatcher.logical import Boot, RetryAction
-from lava_dispatcher.actions.boot import BootHasMixin, AutoLoginAction
+from lava_dispatcher.actions.boot import BootHasMixin, AutoLoginAction, OverlayUnpack
 from lava_dispatcher.shell import ExpectShellSession, ShellCommand, ShellSession
 
 
@@ -59,6 +59,8 @@ class BootFVPAction(BootHasMixin, RetryAction):
             self.pipeline.add_action(AutoLoginAction())
             if self.test_has_shell(parameters):
                 self.pipeline.add_action(ExpectShellSession())
+                if "transfer_overlay" in parameters:
+                    self.pipeline.add_action(OverlayUnpack())
 
 
 class BootFVPMain(Action):
@@ -71,7 +73,8 @@ class BootFVPMain(Action):
         self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         self.pipeline.add_action(CheckFVPVersionAction())
         self.pipeline.add_action(StartFVPAction())
-        self.pipeline.add_action(GetFVPSerialAction())
+        if parameters.get("use_telnet", True):
+            self.pipeline.add_action(GetFVPSerialAction())
 
 
 class BaseFVPAction(Action):
@@ -234,6 +237,8 @@ class StartFVPAction(BaseFVPAction):
         self.container = ""
         self.fvp_image = None
         self.fvp_console_string = ""
+        self.shell = None
+        self.shell_session = None
 
     def validate(self):
         super().validate()
@@ -280,8 +285,20 @@ class StartFVPAction(BaseFVPAction):
             key="container",
             value=self.container,
         )
+        # Although we don't require any more output on this connection,
+        # discarding this may cause SIGHUPs to be sent to the model
+        # which will terminate the model.
+        self.shell = shell
+
+        self.shell_session = shell_connection
         return shell_connection
 
+    def cleanup(self, connection):
+        if self.shell_session:
+            self.logger.debug("Listening to feedback from FVP binary.")
+            self.shell_session.listen_feedback(5)
+        super().cleanup(connection)
+
 
 class GetFVPSerialAction(Action):
     name = "fvp-serial-connect"
