@@ -36,7 +36,7 @@ class OpenOCD(Boot):
 
     @classmethod
     def action(cls):
-        return BootOpenOCD()
+        return BootOpenOCDRetry()
 
     @classmethod
     def accepts(cls, device, parameters):
@@ -51,17 +51,6 @@ class OpenOCD(Boot):
         return True, "accepted"
 
 
-class BootOpenOCD(RetryAction):
-
-    name = "boot-openocd-image"
-    description = "boot openocd image with retry"
-    summary = "boot openocd image with retry"
-
-    def populate(self, parameters):
-        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
-        self.pipeline.add_action(BootOpenOCDRetry())
-
-
 class BootOpenOCDRetry(RetryAction):
 
     name = "boot-openocd-image"
