@@ -21,7 +21,6 @@
 from lava_common.utils import binary_version
 from lava_dispatcher.action import Pipeline, Action, JobError
 from lava_dispatcher.logical import Boot, RetryAction
-from lava_dispatcher.actions.boot import BootAction
 from lava_dispatcher.connections.serial import ConnectDevice
 from lava_dispatcher.utils.shell import which
 from lava_dispatcher.utils.strings import substitute
@@ -33,12 +32,9 @@ class PyOCD(Boot):
 
     compatibility = 4  # FIXME: change this to 5 and update test cases
 
-    def __init__(self, parent, parameters):
-        super().__init__(parent)
-        self.action = BootPyOCD()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
+    @classmethod
+    def action(cls):
+        return BootPyOCD()
 
     @classmethod
     def accepts(cls, device, parameters):
@@ -53,17 +49,15 @@ class PyOCD(Boot):
         return True, "accepted"
 
 
-class BootPyOCD(BootAction):
+class BootPyOCD(RetryAction):
 
     name = "boot-pyocd-image"
     description = "boot pyocd image with retry"
     summary = "boot pyocd image with retry"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
-        )
-        self.internal_pipeline.add_action(BootPyOCDRetry())
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.pipeline.add_action(BootPyOCDRetry())
 
 
 class BootPyOCDRetry(RetryAction):
@@ -73,16 +67,12 @@ class BootPyOCDRetry(RetryAction):
     summary = "boot pyocd image"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
-        )
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         if self.job.device.hard_reset_command:
-            self.internal_pipeline.add_action(ResetDevice())
-            self.internal_pipeline.add_action(
-                WaitDeviceBoardID(self.job.device.get("board_id"))
-            )
-        self.internal_pipeline.add_action(FlashPyOCDAction())
-        self.internal_pipeline.add_action(ConnectDevice())
+            self.pipeline.add_action(ResetDevice())
+            self.pipeline.add_action(WaitDeviceBoardID(self.job.device.get("board_id")))
+        self.pipeline.add_action(FlashPyOCDAction())
+        self.pipeline.add_action(ConnectDevice())
 
 
 class FlashPyOCDAction(Action):
