@@ -311,7 +311,7 @@ class CallQemuAction(Action):
             )
 
         if "docker" in self.parameters:
-            docker = DockerRun(self.parameters["docker"]["image"])
+            docker = DockerRun.from_parameters(self.parameters["docker"])
             docker.interactive()
             docker.tty()
             docker.bind_mount(DISPATCHER_DOWNLOAD_DIR)
@@ -320,6 +320,8 @@ class CallQemuAction(Action):
             if "binary" in self.parameters["docker"]:
                 args.append(self.parameters["docker"]["binary"])
 
+            self.logger.info("Pulling docker image")
+            docker.prepare(action=self)
             self.sub_command[0] = " ".join(docker.cmdline(*args))
 
         self.logger.info("Boot command: %s", " ".join(self.sub_command))
