@@ -29,6 +29,7 @@ from lava_dispatcher.actions.boot.depthcharge import Depthcharge
 from lava_dispatcher.actions.boot.dfu import DFU
 from lava_dispatcher.actions.boot.docker import BootDocker
 from lava_dispatcher.actions.boot.fastboot import BootFastboot
+from lava_dispatcher.actions.boot.fvp import BootFVP
 from lava_dispatcher.actions.boot.gdb import GDB
 from lava_dispatcher.actions.boot.grub import Grub, GrubSequence
 from lava_dispatcher.actions.boot.iso import BootIsoInstaller
@@ -36,6 +37,7 @@ from lava_dispatcher.actions.boot.ipxe import IPXE
 from lava_dispatcher.actions.boot.kexec import BootKExec
 from lava_dispatcher.actions.boot.lxc import BootLxc
 from lava_dispatcher.actions.boot.minimal import Minimal
+from lava_dispatcher.actions.boot.musca import Musca
 from lava_dispatcher.actions.boot.openocd import OpenOCD
 from lava_dispatcher.actions.boot.pyocd import PyOCD
 from lava_dispatcher.actions.boot.jlink import JLink
@@ -47,3 +49,4 @@ from lava_dispatcher.actions.boot.barebox import Barebox
 from lava_dispatcher.actions.boot.uefi import UefiShell
 from lava_dispatcher.actions.boot.uefi_menu import UefiMenu
 from lava_dispatcher.actions.boot.recovery import RecoveryBoot
+from lava_dispatcher.actions.boot.uuu import UUUBoot
