@@ -22,15 +22,14 @@ import re
 import subprocess  # nosec - internal
 
 from lava_common.exceptions import InfrastructureError
-from lava_dispatcher.action import Pipeline
-from lava_dispatcher.actions.deploy import DeployAction
+from lava_dispatcher.action import Action, Pipeline
 from lava_dispatcher.actions.deploy.environment import DeployDeviceEnvironment
 from lava_dispatcher.actions.deploy.overlay import OverlayAction
 from lava_dispatcher.logical import Deployment
 from lava_dispatcher.utils.shell import which
 
 
-class DockerAction(DeployAction):
+class DockerAction(Action):
 
     name = "deploy-docker"
     description = "deploy docker images"
@@ -80,13 +79,11 @@ class DockerAction(DeployAction):
         )
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
-        )
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         if self.test_needs_deployment(parameters):
-            self.internal_pipeline.add_action(DeployDeviceEnvironment())
+            self.pipeline.add_action(DeployDeviceEnvironment())
         if self.test_needs_overlay(parameters):
-            self.internal_pipeline.add_action(OverlayAction())
+            self.pipeline.add_action(OverlayAction())
 
     def run(self, connection, max_end_time):
         # Pull the image
@@ -114,12 +111,9 @@ class Docker(Deployment):
     compatibility = 4
     name = "docker"
 
-    def __init__(self, parent, parameters):
-        super().__init__(parent)
-        self.action = DockerAction()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
+    @classmethod
+    def action(cls):
+        return DockerAction()
 
     @classmethod
     def accepts(cls, device, parameters):
