@@ -19,10 +19,9 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 import os
-from lava_common.exceptions import InfrastructureError
-from lava_dispatcher.action import Pipeline, Action
+
+from lava_dispatcher.action import Action, Pipeline
 from lava_dispatcher.logical import Deployment
-from lava_dispatcher.actions.deploy import DeployAction
 from lava_dispatcher.actions.deploy.download import (
     DownloaderAction,
     QCowConversionAction,
@@ -35,23 +34,21 @@ from lava_dispatcher.actions.deploy.environment import DeployDeviceEnvironment
 from lava_dispatcher.actions.deploy.overlay import OverlayAction
 from lava_dispatcher.utils.compression import untar_file
 
-# pylint: disable=too-many-instance-attributes
 
-
-class DeployImagesAction(DeployAction):  # FIXME: Rename to DeployPosixImages
+class DeployImagesAction(Action):  # FIXME: Rename to DeployPosixImages
 
     name = "deployimages"
     description = "deploy images using guestfs"
     summary = "deploy images"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
-        )
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         path = self.mkdtemp()
         if "uefi" in parameters:
             uefi_path = self.mkdtemp()
-            self.internal_pipeline.add_action(DownloaderAction("uefi", uefi_path))
+            self.pipeline.add_action(
+                DownloaderAction("uefi", uefi_path, params=parameters["uefi"])
+            )
             # uefi option of QEMU needs a directory, not the filename
             self.set_namespace_data(
                 action=self.name,
@@ -62,16 +59,16 @@ class DeployImagesAction(DeployAction):  # FIXME: Rename to DeployPosixImages
             )
             # alternatively use the -bios option and standard image args
         for image in parameters["images"].keys():
-            self.internal_pipeline.add_action(DownloaderAction(image, path))
+            self.pipeline.add_action(
+                DownloaderAction(image, path, params=parameters["images"][image])
+            )
             if parameters["images"][image].get("format", "") == "qcow2":
-                self.internal_pipeline.add_action(QCowConversionAction(image))
+                self.pipeline.add_action(QCowConversionAction(image))
         if self.test_needs_overlay(parameters):
-            self.internal_pipeline.add_action(
-                OverlayAction()
-            )  # idempotent, includes testdef
-            self.internal_pipeline.add_action(ApplyOverlayGuest())
+            self.pipeline.add_action(OverlayAction())  # idempotent, includes testdef
+            self.pipeline.add_action(ApplyOverlayGuest())
         if self.test_needs_deployment(parameters):
-            self.internal_pipeline.add_action(DeployDeviceEnvironment())
+            self.pipeline.add_action(DeployDeviceEnvironment())
 
 
 class DeployQemuNfs(Deployment):
@@ -83,12 +80,9 @@ class DeployQemuNfs(Deployment):
     compatibility = 5
     name = "qemu-nfs"
 
-    def __init__(self, parent, parameters):
-        super().__init__(parent)
-        self.action = DeployQemuNfsAction()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
+    @classmethod
+    def action(cls):
+        return DeployQemuNfsAction()
 
     @classmethod
     def accepts(cls, device, parameters):
@@ -110,20 +104,20 @@ class DeployQemuNfs(Deployment):
         return True, "accepted"
 
 
-class DeployQemuNfsAction(DeployAction):
+class DeployQemuNfsAction(Action):
 
     name = "deploy-qemu-nfs"
     description = "deploy qemu with NFS"
     summary = "deploy NFS for QEMU"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
-        )
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         path = self.mkdtemp()
         if "uefi" in parameters:
             uefi_path = self.mkdtemp()
-            self.internal_pipeline.add_action(DownloaderAction("uefi", uefi_path))
+            self.pipeline.add_action(
+                DownloaderAction("uefi", uefi_path, params=parameters["uefi"])
+            )
             # uefi option of QEMU needs a directory, not the filename
             self.set_namespace_data(
                 action=self.name,
@@ -134,13 +128,17 @@ class DeployQemuNfsAction(DeployAction):
             )
             # alternatively use the -bios option and standard image args
         for image in parameters["images"].keys():
-            self.internal_pipeline.add_action(DownloaderAction(image, path))
+            self.pipeline.add_action(
+                DownloaderAction(image, path, params=parameters["images"][image])
+            )
             if parameters["images"][image].get("format", "") == "qcow2":
-                self.internal_pipeline.add_action(QCowConversionAction(image))
-        self.internal_pipeline.add_action(ExtractNfsAction())
-        self.internal_pipeline.add_action(OverlayAction())
-        self.internal_pipeline.add_action(ApplyOverlayTftp())
-        self.internal_pipeline.add_action(DeployDeviceEnvironment())
+                self.pipeline.add_action(QCowConversionAction(image))
+        self.pipeline.add_action(ExtractNfsAction())
+        if self.test_needs_overlay(parameters):
+            self.pipeline.add_action(OverlayAction())
+            self.pipeline.add_action(ApplyOverlayTftp())
+        if self.test_needs_deployment(parameters):
+            self.pipeline.add_action(DeployDeviceEnvironment())
 
 
 class ExtractNfsAction(Action):
@@ -167,10 +165,6 @@ class ExtractNfsAction(Action):
             action="download-action", label=self.param_key, key="file"
         ):
             self.errors = "no file specified extract as %s" % self.param_key
-        if not os.path.exists("/usr/sbin/exportfs"):
-            raise InfrastructureError(
-                "NFS job requested but nfs-kernel-server not installed."
-            )
         if "prefix" in self.parameters["images"][self.param_key]:
             prefix = self.parameters["images"][self.param_key]["prefix"]
             if prefix.startswith("/"):
@@ -231,12 +225,9 @@ class DeployImages(Deployment):
     compatibility = 4
     name = "images"
 
-    def __init__(self, parent, parameters):
-        super().__init__(parent)
-        self.action = DeployImagesAction()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
+    @classmethod
+    def action(cls):
+        return DeployImagesAction()
 
     @classmethod
     def accepts(cls, device, parameters):
