@@ -24,15 +24,15 @@
 import os
 import tempfile
 
-from lava_dispatcher.action import Pipeline
+from lava_dispatcher.action import Action, Pipeline
 from lava_common.exceptions import JobError
 from lava_dispatcher.logical import Deployment
-from lava_dispatcher.actions.deploy import DeployAction
 from lava_dispatcher.actions.deploy.download import DownloaderAction
 from lava_dispatcher.utils.shell import which
-from lava_dispatcher.utils.filesystem import tftpd_dir
+from lava_dispatcher.utils import filesystem
 from lava_dispatcher.protocols.xnbd import XnbdProtocol
 from lava_dispatcher.actions.deploy.overlay import OverlayAction
+from lava_dispatcher.actions.deploy.prepare import PrepareKernelAction
 
 
 class Nbd(Deployment):
@@ -45,27 +45,24 @@ class Nbd(Deployment):
     """
 
     compatibility = 1
-    name = 'nbd'
+    name = "nbd"
 
-    def __init__(self, parent, parameters):
-        super().__init__(parent)
-        self.action = NbdAction()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
+    @classmethod
+    def action(cls):
+        return NbdAction()
 
     @classmethod
     def accepts(cls, device, parameters):
-        if 'to' not in parameters:
+        if "to" not in parameters:
             return False, '"to" is not in deploy parameters'
-        if parameters['to'] != 'nbd':
+        if parameters["to"] != "nbd":
             return False, '"to" parameter is not "nbd"'
-        if 'nbd' in device['actions']['deploy']['methods']:
-            return True, 'accepted'
+        if "nbd" in device["actions"]["deploy"]["methods"]:
+            return True, "accepted"
         return False, '"ndb" was not in the device configuration deploy methods'
 
 
-class NbdAction(DeployAction):  # pylint:disable=too-many-instance-attributes
+class NbdAction(Action):
 
     name = "nbd-deploy"
     description = "download files and deploy for using tftp+initrd+nbd"
@@ -79,63 +76,96 @@ class NbdAction(DeployAction):  # pylint:disable=too-many-instance-attributes
 
     def validate(self):
         super().validate()
-        if 'kernel' not in self.parameters:
+        if "kernel" not in self.parameters:
             self.errors = "%s needs a kernel to deploy" % self.name
         if not self.valid:
             return
-        if 'nbdroot' not in self.parameters:
+        if "nbdroot" not in self.parameters:
             self.errors = "NBD deployment needs a 'nbdroot' parameter"
-        if 'initrd' not in self.parameters:
+        if "initrd" not in self.parameters:
             self.errors = "NBD deployment needs an 'initrd' parameter"
         # we cannot work with these when using nbd
-        if 'nfsrootfs' in self.parameters or 'nfs_url' in self.parameters:
-            self.errors = "nfsrootfs or nfs_url cannot be used with NBD deployment, use a e.g. ext3/4 filesystem as 'nbdroot=' parameter"
-        if 'ramdisk' in self.parameters:
+        if "nfsrootfs" in self.parameters:
+            self.errors = "nfsrootfs cannot be used with NBD deployment, use a e.g. ext3/4 filesystem as 'nbdroot=' parameter"
+        if "ramdisk" in self.parameters:
             self.errors = "ramdisk cannot be used with NBD deployment, use a e.g. ext3/4 filesystem as 'initrd' parameter"
 
         # Extract the 3 last path elements. See action.mkdtemp()
-        suffix = os.path.join(*self.tftp_dir.split('/')[-2:])
-        self.set_namespace_data(action="tftp-deploy", label='tftp', key='suffix', value=suffix)
+        suffix = os.path.join(*self.tftp_dir.split("/")[-2:])
+        self.set_namespace_data(
+            action="tftp-deploy", label="tftp", key="suffix", value=suffix
+        )
         # we need tftp _and_ xnbd-server
-        which('in.tftpd')
-        which('xnbd-server')
+        which("in.tftpd")
+        which("xnbd-server")
 
         # Check that the tmp directory is in the nbdd_dir or in /tmp for the
         # unit tests
-        tftpd_directory = os.path.realpath(tftpd_dir())
+        tftpd_directory = os.path.realpath(filesystem.tftpd_dir())
         tftp_dir = os.path.realpath(self.tftp_dir)
         tmp_dir = tempfile.gettempdir()
-        if not tftp_dir.startswith(tftpd_directory) and \
-           not tftp_dir.startswith(tmp_dir):
+        if not tftp_dir.startswith(tftpd_directory) and not tftp_dir.startswith(
+            tmp_dir
+        ):
             self.errors = "tftpd directory is not configured correctly, see /etc/default/tftpd-hpa"
 
     def populate(self, parameters):
-        self.tftp_dir = self.mkdtemp(override=tftpd_dir())
-        self.internal_pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
-        self.set_namespace_data(action=self.name, label='tftp', key='tftp_dir', value=self.tftp_dir, parameters=parameters)
+        self.tftp_dir = self.mkdtemp(override=filesystem.tftpd_dir())
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.set_namespace_data(
+            action=self.name,
+            label="tftp",
+            key="tftp_dir",
+            value=self.tftp_dir,
+            parameters=parameters,
+        )
 
-        for key in ['initrd', 'kernel', 'dtb', 'nbdroot']:
+        for key in ["initrd", "kernel", "dtb", "nbdroot"]:
             if key in parameters:
-                download = DownloaderAction(key, path=self.tftp_dir)
-                download.max_retries = 3  # overridden by failure_retry in the parameters, if set.
-                self.internal_pipeline.add_action(download)
-                if key == 'initrd':
-                    self.set_namespace_data(action="tftp-deploy", label='tftp', key='ramdisk', value=True, parameters=parameters)
-                    self.set_namespace_data(action=self.name, label='nbd', key='initrd', value=True, parameters=parameters)
+                download = DownloaderAction(
+                    key, path=self.tftp_dir, params=parameters[key]
+                )
+                download.max_retries = (
+                    3  # overridden by failure_retry in the parameters, if set.
+                )
+                self.pipeline.add_action(download)
+                if key == "initrd":
+                    self.set_namespace_data(
+                        action="tftp-deploy",
+                        label="tftp",
+                        key="ramdisk",
+                        value=True,
+                        parameters=parameters,
+                    )
+                    self.set_namespace_data(
+                        action=self.name,
+                        label="nbd",
+                        key="initrd",
+                        value=True,
+                        parameters=parameters,
+                    )
 
         # prepare overlay
-        self.internal_pipeline.add_action(OverlayAction())
+        self.pipeline.add_action(OverlayAction())
+        if "kernel" in parameters and "type" in parameters["kernel"]:
+            self.pipeline.add_action(PrepareKernelAction())
         # setup values for protocol and later steps
-        self.set_namespace_data(action=self.name, label='nbd', key='initrd', value=True, parameters=parameters)
+        self.set_namespace_data(
+            action=self.name,
+            label="nbd",
+            key="initrd",
+            value=True,
+            parameters=parameters,
+        )
         # store in parameters for protocol 'xnbd' to tear-down xnbd-server
         # and store in namespace for boot action
         # ip
-        parameters['lava-xnbd'] = {}
+        parameters["lava-xnbd"] = {}
         # handle XnbdAction next - bring-up xnbd-server
-        self.internal_pipeline.add_action(XnbdAction())
+        self.pipeline.add_action(XnbdAction())
 
 
-class XnbdAction(DeployAction):
+class XnbdAction(Action):
 
     name = "xnbd-server-deploy"
     description = "xnbd daemon"
@@ -151,22 +181,36 @@ class XnbdAction(DeployAction):
         connection = super().run(connection, max_end_time)
         self.logger.debug("%s: starting xnbd-server", self.name)
         # pull from parameters - as previously set
-        self.nbd_root = self.parameters['lava-xnbd']['nbdroot']
-        self.nbd_server_port = self.get_namespace_data(action='nbd-deploy', label='nbd', key='nbd_server_port')
-        self.nbd_server_ip = self.get_namespace_data(action='nbd-deploy', label='nbd', key='nbd_server_ip')
+        self.nbd_root = self.parameters["lava-xnbd"]["nbdroot"]
+        self.nbd_server_port = self.get_namespace_data(
+            action="nbd-deploy", label="nbd", key="nbd_server_port"
+        )
+        self.nbd_server_ip = self.get_namespace_data(
+            action="nbd-deploy", label="nbd", key="nbd_server_ip"
+        )
         if self.nbd_server_port is None:
             self.errors = "NBD server port is unset"
             return connection
-        self.logger.debug("NBD-IP: %s, NBD-PORT: %s, NBD-ROOT: %s",
-                          self.nbd_server_ip, self.nbd_server_port, self.nbd_root)
-        nbd_cmd = ['xnbd-server', '--logpath', '/tmp/xnbd.log.%s' % self.nbd_server_port,
-                   '--daemon', '--target', '--lport', '%s' % self.nbd_server_port,
-                   '%s/%s' % (os.path.realpath(tftpd_dir()),
-                              self.nbd_root)]
+        self.logger.debug(
+            "NBD-IP: %s, NBD-PORT: %s, NBD-ROOT: %s",
+            self.nbd_server_ip,
+            self.nbd_server_port,
+            self.nbd_root,
+        )
+        nbd_cmd = [
+            "xnbd-server",
+            "--logpath",
+            "/tmp/xnbd.log.%s" % self.nbd_server_port,
+            "--daemon",
+            "--target",
+            "--lport",
+            "%s" % self.nbd_server_port,
+            "%s/%s" % (os.path.realpath(filesystem.tftpd_dir()), self.nbd_root),
+        ]
         command_output = self.run_command(nbd_cmd, allow_fail=False)
 
-        if command_output and 'error' in command_output:
-            raise JobError('xnbd-server: %s' % command_output)
+        if command_output and "error" in command_output:
+            raise JobError("xnbd-server: %s" % command_output)
         else:
             self.logger.debug("%s: starting xnbd-server done", self.name)
         return connection
