@@ -19,6 +19,7 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 import os
+import shlex
 import stat
 import glob
 import shutil
@@ -169,7 +170,7 @@ class CreateOverlay(Action):
             elif isinstance(data, int):
                 data = data
             else:
-                data = "'%s'" % data
+                data = shlex.quote(data)
             self.logger.debug("- %s=%s", prefix, data)
             fout.write("export %s=%s\n" % (prefix, data))
 
@@ -253,6 +254,10 @@ class CreateOverlay(Action):
                 self.logger.debug("job environment:")
                 self._export_data(fout, data, "")
 
+            # TODO: Add LAVA_URL?
+            self.logger.debug("LAVA metadata")
+            self._export_data(fout, self.job.job_id, "LAVA_JOB_ID")
+
         # Generate the file containing the secrets
         if "secrets" in self.job.parameters:
             self.logger.debug("Creating %s/secrets", lava_path)
