@@ -25,8 +25,7 @@ import os
 import shutil
 from lava_common.exceptions import JobError, InfrastructureError, LAVABug
 from lava_dispatcher.action import Action, Pipeline
-from lava_dispatcher.logical import Deployment
-from lava_dispatcher.actions.deploy import DeployAction
+from lava_dispatcher.logical import Deployment, RetryAction
 from lava_dispatcher.actions.deploy.lxc import LxcCreateUdevRuleAction
 from lava_dispatcher.actions.deploy.download import DownloaderAction
 from lava_dispatcher.connections.serial import ConnectDevice
@@ -50,12 +49,9 @@ class VExpressMsd(Deployment):
     compatibility = 1
     name = "vemsd"
 
-    def __init__(self, parent, parameters):
-        super().__init__(parent)
-        self.action = VExpressMsdAction()
-        self.action.section = self.action_type
-        self.action.job = self.job
-        parent.add_action(self.action, parameters)
+    @classmethod
+    def action(cls):
+        return VExpressMsdRetry()
 
     @classmethod
     def uses_deployment_data(cls):
@@ -73,7 +69,18 @@ class VExpressMsd(Deployment):
         return False, '"vemsd" was not in the device configuration deploy methods'
 
 
-class VExpressMsdAction(DeployAction):
+class VExpressMsdRetry(RetryAction):
+
+    name = "vexpress-fw-deploy-retry"
+    description = "deploy vexpress board recovery image with retry"
+    summary = "VExpress FW deployment with retry"
+
+    def populate(self, parameters):
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.pipeline.add_action(VExpressMsdAction())
+
+
+class VExpressMsdAction(Action):
     """
     Action for deploying firmware to a Versatile Express board
     in the form of a board recovery image.
@@ -90,24 +97,27 @@ class VExpressMsdAction(DeployAction):
 
     def populate(self, parameters):
         download_dir = self.mkdtemp()
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
+        self.pipeline.add_action(
+            DownloaderAction(
+                "recovery_image", path=download_dir, params=parameters["recovery_image"]
+            )
         )
-        self.internal_pipeline.add_action(
-            DownloaderAction("recovery_image", path=download_dir)
-        )
-        self.internal_pipeline.add_action(LxcCreateUdevRuleAction())
+        self.pipeline.add_action(LxcCreateUdevRuleAction())
         self.force_prompt = True
-        self.internal_pipeline.add_action(ConnectDevice())
-        self.internal_pipeline.add_action(ResetDevice())
-        self.internal_pipeline.add_action(ExtractVExpressRecoveryImage())
-        self.internal_pipeline.add_action(EnterVExpressMCC())
-        self.internal_pipeline.add_action(EnableVExpressMassStorage())
-        self.internal_pipeline.add_action(WaitUSBMassStorageDeviceAction())
-        self.internal_pipeline.add_action(MountVExpressMassStorageDevice())
-        self.internal_pipeline.add_action(DeployVExpressRecoveryImage())
-        self.internal_pipeline.add_action(UnmountVExpressMassStorageDevice())
-        self.internal_pipeline.add_action(VExpressFlashErase())
+        self.pipeline.add_action(ConnectDevice())
+        self.pipeline.add_action(ResetDevice())
+        self.pipeline.add_action(ExtractVExpressRecoveryImage())
+        self.pipeline.add_action(EnterVExpressMCC())
+        self.pipeline.add_action(EnableVExpressMassStorage())
+        self.pipeline.add_action(WaitUSBMassStorageDeviceAction())
+        self.pipeline.add_action(MountVExpressMassStorageDevice())
+        self.pipeline.add_action(DeployVExpressRecoveryImage())
+        self.pipeline.add_action(UnmountVExpressMassStorageDevice())
+        if self.job.device["actions"]["deploy"]["methods"]["vemsd"]["parameters"].get(
+            "flash_prompt", False
+        ):
+            self.pipeline.add_action(VExpressFlashErase())
 
 
 class ExtractVExpressRecoveryImage(Action):
@@ -140,6 +150,12 @@ class ExtractVExpressRecoveryImage(Action):
     def run(self, connection, max_end_time):
         connection = super().run(connection, max_end_time)
 
+        recovery_image_dir = self.get_namespace_data(
+            action="extract-vexpress-recovery-image", label="file", key=self.file_key
+        )
+        if recovery_image_dir:
+            self.logger.debug("Clearing existing data at %s", recovery_image_dir)
+            shutil.rmtree(recovery_image_dir)
         # copy recovery image to a temporary directory and unpack
         recovery_image = self.get_namespace_data(
             action="download-action", label=self.param_key, key="file"
@@ -277,37 +293,38 @@ class EnableVExpressMassStorage(Action):
         return connection
 
 
-class MountVExpressMassStorageDevice(Action):
+class MountDeviceMassStorageDevice(Action):
     """
-    Mounts Versatile Express USB mass storage device on the dispatcher.
-    The device is identified by the filesystem label given when running the
-    format command on the Versatile Express board.
+    Generic action to mount a device's mass storage device, with a range of identifiers.
     """
 
-    name = "mount-vexpress-usbmsd"
-    description = "mount vexpress usb msd"
-    summary = "mount vexpress usb mass storage device on the dispatcher"
+    name = "mount-device-usbmsd"
+    description = "mount device usb msd"
+    summary = "mount device usb mass storage device on the dispatcher"
     command_exception = InfrastructureError
     timeout_exception = InfrastructureError
 
     def __init__(self):
         super().__init__()
-        self.microsd_fs_label = None
-
-    def validate(self):
-        super().validate()
-        self.microsd_fs_label = self.job.device.get("usb_filesystem_label")
-        if not isinstance(self.microsd_fs_label, str):
-            self.errors = "Filesystem label unset for Versatile Express"
+        self.device_name = None
+        self.disk_identifier = None
+        self.disk_identifier_type = None  # uuid, id, label
+        self.namespace_label = None
 
     def run(self, connection, max_end_time):
         connection = super().run(connection, max_end_time)
 
-        device_path = "/dev/disk/by-label/%s" % self.microsd_fs_label
+        device_path = "/dev/disk/by-%s/%s" % (
+            self.disk_identifier_type,
+            self.disk_identifier,
+        )
         if not os.path.exists(device_path):
-            raise InfrastructureError("Unable to find disk by label %s" % device_path)
+            raise InfrastructureError(
+                "Unable to find disk by %s %s"
+                % (self.disk_identifier_type, device_path)
+            )
 
-        mount_point = "/mnt/%s" % self.microsd_fs_label
+        mount_point = "/mnt/%s" % self.disk_identifier
         if not os.path.exists(mount_point):
             try:
                 self.logger.debug("Creating mount point '%s'", mount_point)
@@ -323,10 +340,47 @@ class MountVExpressMassStorageDevice(Action):
         )
 
         self.set_namespace_data(
-            action=self.name, label="vexpress-fw", key="mount-point", value=mount_point
+            action=self.name,
+            label=self.namespace_label,
+            key="mount-point",
+            value=mount_point,
         )
         return connection
 
+    def cleanup(self, connection):
+        mount_point = "/mnt/%s" % self.disk_identifier
+        if os.path.ismount(mount_point):
+            self.logger.debug("Unmounting %s", mount_point)
+            self.run_cmd(
+                ["umount", mount_point],
+                error_msg="Failed to unmount device at %s" % mount_point,
+            )
+
+
+class MountVExpressMassStorageDevice(MountDeviceMassStorageDevice):
+    """
+    Mounts Versatile Express USB mass storage device on the dispatcher.
+    The device is identified by the filesystem label given when running the
+    format command on the Versatile Express board.
+    """
+
+    name = "mount-vexpress-usbmsd"
+    description = "mount vexpress usb msd"
+    summary = "mount vexpress usb mass storage device on the dispatcher"
+
+    def __init__(self):
+        super().__init__()
+        self.device_name = "Versatile Express"
+        self.disk_identifier = None
+        self.disk_identifier_type = "label"
+        self.namespace_label = "vexpress-fw"
+
+    def validate(self):
+        super().validate()
+        self.disk_identifier = self.job.device.get("usb_filesystem_label")
+        if not isinstance(self.disk_identifier, str):
+            self.errors = "Filesystem %s unset for " + self.device_name
+
 
 class DeployVExpressRecoveryImage(Action):
     """
@@ -383,11 +437,16 @@ class UnmountVExpressMassStorageDevice(Action):
     command_exception = InfrastructureError
     timeout_exception = InfrastructureError
 
+    def __init__(self):
+        super().__init__()
+        self.namespace_label = "vexpress-fw"
+        self.namespace_action = "mount-vexpress-usbmsd"
+
     def run(self, connection, max_end_time):
         connection = super().run(connection, max_end_time)
 
         mount_point = self.get_namespace_data(
-            action="mount-vexpress-usbmsd", label="vexpress-fw", key="mount-point"
+            action=self.namespace_action, label=self.namespace_label, key="mount-point"
         )
         self.run_cmd(
             ["sync", mount_point], error_msg="Failed to sync device %s" % mount_point
@@ -399,7 +458,7 @@ class UnmountVExpressMassStorageDevice(Action):
         return connection
 
 
-class VExpressFlashErase(Action):  # pylint: disable=too-many-instance-attributes
+class VExpressFlashErase(Action):
     """
     Enter Versatile Express Flash menu and erase NOR Flash.
     The job writer can define whether this should be a range or all.
