@@ -117,6 +117,10 @@ class TestInteractiveAction(Action):
         # Loop on all scripts
         for script in self.parameters["interactive"]:
             start = time.time()
+
+            # Set the connection prompts
+            connection.prompt_str = script["prompts"]
+
             result = {
                 "definition": "lava",
                 "case": "%s_%s" % (self.parameters["stage"], script["name"]),
@@ -131,9 +135,6 @@ class TestInteractiveAction(Action):
                 result["duration"] = "%.02f" % (time.time() - start)
                 self.logger.results(result)
 
-            # Set the connection prompts
-            connection.prompt_str = script["prompts"]
-
         return connection
 
     def run_script(self, test_connection, script, substitutions):
@@ -161,6 +162,7 @@ class TestInteractiveAction(Action):
                 self.logger.info("send result: %r", res)
                 continue
             elif "lava-wait" in cmd:
+                self.multinode_proto.set_timeout(self.timeout.duration)
                 res = self.multinode_proto.request_wait(cmd["lava-wait"])
                 self.logger.info("wait result: %r", res)
                 res = json.loads(res)
@@ -181,6 +183,7 @@ class TestInteractiveAction(Action):
                             "lava-wait-all 2nd param must be role=<rolename>, got: %s"
                             % key
                         )
+                self.multinode_proto.set_timeout(self.timeout.duration)
                 res = self.multinode_proto.request_wait_all(parts[0], role)
                 self.logger.info("wait-all result: %r", res)
                 res = json.loads(res)
@@ -192,6 +195,7 @@ class TestInteractiveAction(Action):
                 multinode2subst(res["message"])
                 continue
             elif "lava-sync" in cmd:
+                self.multinode_proto.set_timeout(self.timeout.duration)
                 res = self.multinode_proto.request_sync(cmd["lava-sync"])
                 self.logger.info("sync result: %r", res)
                 continue
@@ -284,4 +288,4 @@ class TestInteractiveAction(Action):
         elif exc_name == "TestError":
             raise TestError(exc_message)
         else:
-            raise JobError("Unknow exception '%s' with '%s'" % (exc_name, exc_message))
+            raise JobError("Unknown exception '%s' with '%s'" % (exc_name, exc_message))
