@@ -40,9 +40,10 @@ class SignalMatch(InternalObject):
             # Special cases for 'measurement'
             if key == "measurement":
                 try:
-                    res["measurement"] = decimal.Decimal(data["measurement"])
+                    measurement = decimal.Decimal(data["measurement"])
                 except decimal.InvalidOperation:
                     raise TestError("Invalid measurement %s" % data["measurement"])
+                res["measurement"] = float(measurement)
 
             # and 'result'
             elif key == "result":
@@ -245,6 +246,9 @@ class Protocol:
     def finalise_protocol(self, device=None):
         raise LAVABug("'finalise_protocol' not implemented")
 
+    def set_timeout(self, duration):
+        self.poll_timeout.duration = duration
+
     def check_timeout(self, duration, data):
         """
         Use if particular protocol calls can require a connection timeout
