@@ -36,19 +36,6 @@ from lava_dispatcher.protocols.multinode import (  # pylint: disable=unused-impo
 from lava_common.constants import DISPATCHER_DOWNLOAD_DIR
 
 
-class ZMQConfig:
-    """
-    Namespace for the ZMQ logging configuration
-    """
-
-    def __init__(self, logging_url, master_cert, slave_cert, socks_proxy, ipv6):
-        self.logging_url = logging_url
-        self.master_cert = master_cert
-        self.slave_cert = slave_cert
-        self.socks_proxy = socks_proxy
-        self.ipv6 = ipv6
-
-
 class Job:
     """
     Populated by the parser, the Job contains all of the
