@@ -28,8 +28,6 @@ from lava_common.exceptions import InfrastructureError, JobError, TestError
 from lava_common.constants import REBOOT_COMMAND_LIST
 from lava_dispatcher.action import Action, Pipeline
 
-# pylint: disable=missing-docstring
-
 
 class ResetDevice(Action):
     """
@@ -43,13 +41,11 @@ class ResetDevice(Action):
     summary = "reboot the device"
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            parent=self, job=self.job, parameters=parameters
-        )
+        self.pipeline = Pipeline(parent=self, job=self.job, parameters=parameters)
         if self.job.device.hard_reset_command:
-            self.internal_pipeline.add_action(PDUReboot())
+            self.pipeline.add_action(PDUReboot())
         else:
-            self.internal_pipeline.add_action(SendRebootCommands())
+            self.pipeline.add_action(SendRebootCommands())
 
 
 class SendRebootCommands(Action):
@@ -63,23 +59,31 @@ class SendRebootCommands(Action):
 
     def run(self, connection, max_end_time):
         connection = super().run(connection, max_end_time)
-        reboot_commands = self.parameters.get("soft_reboot", [])  # list
-        if not self.parameters.get("soft_reboot"):  # unit test
+        if "soft_reboot" in self.parameters:
+            commands = self.parameters["soft_reboot"]
+        elif self.job.device.soft_reboot_command:
+            commands = self.job.device.soft_reboot_command
+        else:
             self.logger.warning(
                 "No soft reboot command defined in the test job. Using defaults."
             )
-            reboot_commands = REBOOT_COMMAND_LIST
+            commands = REBOOT_COMMAND_LIST
+
+        # Accept both str and [str]
+        if isinstance(commands, str):
+            commands = [commands]
+
         connection.prompt_str = self.parameters.get("parameters", {}).get(
             "shutdown-message", self.job.device.get_constant("shutdown-message")
         )
         connection.timeout = self.connection_timeout
-        for cmd in reboot_commands:
+        for cmd in commands:
             connection.sendline(cmd)
         try:
             self.wait(connection)
         except TestError:
             raise JobError("Soft reboot failed.")
-        self.results = {"commands": reboot_commands}
+        self.results = {"commands": commands}
         return connection
 
 
@@ -260,7 +264,7 @@ class ReadFeedback(Action):
 
     def run(self, connection, max_end_time):
         feedbacks = []
-        for feedback_ns in self.data.keys():  # pylint: disable=no-member
+        for feedback_ns in self.data.keys():
             if feedback_ns == self.parameters.get("namespace"):
                 if not self.repeat:
                     continue
@@ -311,17 +315,15 @@ class FinalizeAction(Action):
         self.ran = False
 
     def populate(self, parameters):
-        self.internal_pipeline = Pipeline(
-            job=self.job, parent=self, parameters=parameters
-        )
-        self.internal_pipeline.add_action(PowerOff())
-        self.internal_pipeline.add_action(ReadFeedback(finalize=True, repeat=True))
+        self.pipeline = Pipeline(job=self.job, parent=self, parameters=parameters)
+        self.pipeline.add_action(PowerOff())
+        self.pipeline.add_action(ReadFeedback(finalize=True, repeat=True))
 
     def run(self, connection, max_end_time):
         """
         The pexpect.spawn here is the ShellCommand not the ShellSession connection object.
         So call the finalise() function of the connection which knows about the raw_connection inside.
-        The internal_pipeline of FinalizeAction is special - it needs to run even in the case of error / cancel.
+        The pipeline of FinalizeAction is special - it needs to run even in the case of error / cancel.
         """
         self.ran = True
         try:
