@@ -20,11 +20,13 @@
 import logging
 from pathlib import Path
 import subprocess
+import time
 
 
 class DockerRun:
     def __init__(self, image):
         self.image = image
+        self.__local__ = False
         self.__name__ = None
         self.__hostname__ = None
         self.__workdir__ = None
@@ -33,6 +35,18 @@ class DockerRun:
         self.__environment__ = []
         self.__interactive__ = False
         self.__tty__ = False
+        self.__docker_options__ = []
+        self.__docker_run_options__ = []
+
+    @classmethod
+    def from_parameters(cls, params):
+        image = params["image"]
+        run = cls(image)
+        run.local(params.get("local", False))
+        return run
+
+    def local(self, local):
+        self.__local__ = local
 
     def name(self, name):
         self.__name__ = name
@@ -50,6 +64,12 @@ class DockerRun:
             return
         self.__devices__.append(device)
 
+    def add_docker_options(self, *options):
+        self.__docker_options__ += options
+
+    def add_docker_run_options(self, *options):
+        self.__docker_run_options__ += options
+
     def interactive(self):
         self.__interactive__ = True
 
@@ -65,7 +85,12 @@ class DockerRun:
         self.__environment__.append((variable, value))
 
     def cmdline(self, *args):
-        cmd = ["docker", "run", "--rm"]
+        cmd = (
+            ["docker"]
+            + self.__docker_options__
+            + ["run", "--rm", "--init"]
+            + self.__docker_run_options__
+        )
         if self.__interactive__:
             cmd.append("--interactive")
         if self.__tty__:
@@ -90,14 +115,67 @@ class DockerRun:
         return cmd
 
     def run(self, *args, action=None):
+        self.prepare(action)
         cmd = self.cmdline(*args)
-        self.__check_image_arch__()
+        self.run_cmd(cmd, action=action)
+
+    def run_cmd(self, cmd, action=None):
         if action:
-            run_cmd = action.run_cmd
+            runner = action.run_cmd
         else:
-            run_cmd = subprocess.check_call
-        run_cmd(["docker", "pull", self.image])
-        run_cmd(cmd)
+            runner = subprocess.check_call
+        runner(cmd)
+
+    def prepare(self, action=None):
+        if self.__local__:
+            self.run_cmd(
+                [
+                    "docker",
+                    "image",
+                    "inspect",
+                    f"--format=Image {self.image} exists locally",
+                    self.image,
+                ],
+                action=action,
+            )
+        else:
+            self.run_cmd(["docker", "pull", self.image], action=action)
+        self.__check_image_arch__()
+
+    def wait(self):
+        delay = 1
+        while True:
+            try:
+                subprocess.check_call(
+                    ["docker", "inspect", "--format=.", self.__name__],
+                    stdout=subprocess.DEVNULL,
+                    stderr=subprocess.DEVNULL,
+                )
+                return
+            except subprocess.CalledProcessError:
+                time.sleep(delay)
+                delay = delay * 2  # exponential backoff
+
+    def wait_file(self, filename):
+        delay = 1
+        while True:
+            try:
+                subprocess.check_call(
+                    ["docker", "exec", self.__name__, "test", "-e", filename],
+                    stdout=subprocess.DEVNULL,
+                    stderr=subprocess.DEVNULL,
+                )
+                return
+            except subprocess.CalledProcessError:
+                time.sleep(delay)
+                delay = delay * 2  # exponential backoff
+
+    def destroy(self):
+        subprocess.call(
+            ["docker", "rm", "-f", self.__name__],
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
+        )
 
     def __check_image_arch__(self):
         host = subprocess.check_output(["arch"], text=True).strip()
