@@ -62,7 +62,7 @@ def mkdtemp(autoremove=True, basedir="/tmp"):  # nosec - internal use.
     return tmpdir
 
 
-def check_ssh_identity_file(params):  # pylint: disable=too-many-return-statements
+def check_ssh_identity_file(params):
     """
     Return a tuple based on if an identity file can be determine in the params.
     If the first value returned is not None, an error occurred.
@@ -216,7 +216,7 @@ def copy_in_overlay(image, root_partition, overlay):
     guest.add_drive(image)
     _launch_guestfs(guest)
 
-    if root_partition:
+    if root_partition is not None:
         partitions = guest.list_partitions()
         if not partitions:
             raise InfrastructureError("Unable to prepare guestfs")
@@ -236,7 +236,7 @@ def copy_in_overlay(image, root_partition, overlay):
     decompressed_overlay = decompress_file(overlay, "gz")
     guest.tar_in(decompressed_overlay, "/")
 
-    if root_partition:
+    if root_partition is not None:
         guest.umount(guest_partition)
     else:
         guest.umount(devices[0])
@@ -297,8 +297,9 @@ def copy_to_lxc(lxc_name, src, dispatcher_config):
         logger.debug("Copying %s to %s", filename, lxc_name)
         try:
             shutil.copyfile(src, dst)
-        except OSError:
-            raise JobError("Unable to copy image: %s" % src)
+        except OSError as exc:
+            logger.error("Unable to copy %s to lxc: %s", src, exc.strerror)
+            raise JobError("Unable to copy %s to lxc: %s" % (src, exc.strerror))
 
     return os.path.join(LAVA_LXC_HOME, filename)
 
@@ -372,7 +373,7 @@ def copy_overlay_to_sparse_fs(image, overlay):
     logger.debug(output)
     _, _, _, available, percent, _ = output.split("\n")[1].split()
     guest.umount(devices[0])
-    if int(available) is 0 or percent == "100%":
+    if int(available) == 0 or percent == "100%":
         raise JobError("No space in image after applying overlay: %s" % image)
 
 
@@ -413,6 +414,6 @@ def is_sparse_image(image):
     """
     Returns True if the image is an 'Android sparse image' else False.
     """
-    image_magic = magic.open(magic.MAGIC_NONE)  # pylint: disable=no-member
+    image_magic = magic.open(magic.MAGIC_NONE)
     image_magic.load()
     return bool(image_magic.file(image).split(",")[0] == "Android sparse image")
