@@ -32,7 +32,7 @@ from lava_common.constants import (
     METADATA_MESSAGE_LIMIT,
 )
 from lava_dispatcher.utils.strings import seconds_to_str
-from lava_dispatcher.log import YAMLLogger
+from lava_common.log import YAMLLogger
 
 
 class LinuxKernelMessages(Action):
@@ -85,9 +85,7 @@ class LinuxKernelMessages(Action):
         return [prompt[1] for prompt in cls.MESSAGE_CHOICES[: cls.FREE_UNUSED]]
 
     @classmethod
-    def parse_failures(
-        cls, connection, action=None, max_end_time=None, fail_msg=None
-    ):  # pylint: disable=too-many-branches
+    def parse_failures(cls, connection, action=None, max_end_time=None, fail_msg=None):
         """
         Returns a list of dictionaries of matches for failure strings and
         other kernel messages.
@@ -147,7 +145,7 @@ class LinuxKernelMessages(Action):
                     "Matched prompt #%s: %s", index, connection.prompt_str[index]
                 )
             message = connection.raw_connection.after
-            if index == cls.TRACE or index == cls.EXCEPTION:
+            if index in [cls.TRACE, cls.EXCEPTION]:
                 res = "fail"
                 if action:
                     action.logger.warning(
@@ -207,7 +205,7 @@ class LinuxKernelMessages(Action):
         # record a specific result for the kernel messages for later debugging.
         if action and isinstance(action.logger, YAMLLogger):
             action.logger.results(
-                {  # pylint: disable=no-member
+                {
                     "definition": "lava",
                     "namespace": action.parameters.get("namespace", "common"),
                     "case": cls.name,
