@@ -27,40 +27,60 @@ import contextlib
 import os
 import netifaces
 import random
+import requests
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.util.retry import Retry
 import socket
 import subprocess  # nosec - internal use.
-from lava_common.exceptions import InfrastructureError
+
+from lava_common.exceptions import InfrastructureError, LAVABug
 from lava_common.constants import (
     XNBD_PORT_RANGE_MIN,
     XNBD_PORT_RANGE_MAX,
+    VALID_DISPATCHER_IP_PROTOCOLS,
 )
 
-# pylint: disable=no-member
-
 
 def dispatcher_gateway():
     """
     Retrieves the IP address of the current default gateway.
     """
     gateways = netifaces.gateways()
-    if 'default' not in gateways:
+    if "default" not in gateways:
         raise InfrastructureError("Unable to find default gateway")
-    return gateways['default'][netifaces.AF_INET][0]
+    return gateways["default"][netifaces.AF_INET][0]
 
 
-def dispatcher_ip(dispatcher_config):
+def dispatcher_ip(dispatcher_config, protocol=None):
     """
     Retrieves the IP address of the interface associated
     with the current default gateway.
+    :param protocol: 'http', 'tftp' or 'nfs'
     """
+    if protocol:
+        if protocol not in VALID_DISPATCHER_IP_PROTOCOLS:
+            raise LAVABug(
+                "protocol should be one of %s" % VALID_DISPATCHER_IP_PROTOCOLS
+            )
+        with contextlib.suppress(KeyError, TypeError):
+            return dispatcher_config["dispatcher_%s_ip" % protocol]
     with contextlib.suppress(KeyError, TypeError):
         return dispatcher_config["dispatcher_ip"]
     gateways = netifaces.gateways()
-    if 'default' not in gateways:
+    if "default" not in gateways:
         raise InfrastructureError("Unable to find dispatcher 'default' gateway")
-    iface = gateways['default'][netifaces.AF_INET][1]
-    addr = netifaces.ifaddresses(iface)
-    return addr[netifaces.AF_INET][0]['addr']
+    iface = gateways["default"][netifaces.AF_INET][1]
+    iface_addr = None
+
+    try:
+        addr = netifaces.ifaddresses(iface)
+        iface_addr = addr[netifaces.AF_INET][0]["addr"]
+    except KeyError:
+        # TODO: This only handles first alias interface can be extended
+        # to review all alias interfaces.
+        addr = netifaces.ifaddresses(iface + ":0")
+        iface_addr = addr[netifaces.AF_INET][0]["addr"]
+    return iface_addr
 
 
 def rpcinfo_nfs(server, version=3):
@@ -70,8 +90,12 @@ def rpcinfo_nfs(server, version=3):
     :param server: the NFS server to check
     :return: None if success, message if fail
     """
-    with open(os.devnull, 'w') as devnull:
-        proc = subprocess.Popen(['/usr/sbin/rpcinfo', '-u', server, 'nfs', "%s" % version], stdout=devnull, stderr=subprocess.PIPE)  # nosec - internal use.
+    with open(os.devnull, "w") as devnull:
+        proc = subprocess.Popen(  # nosec - internal use.
+            ["/usr/sbin/rpcinfo", "-u", server, "nfs", "%s" % version],
+            stdout=devnull,
+            stderr=subprocess.PIPE,
+        )
         msg = proc.communicate()
         if msg[1]:
             return "%s %s" % (server, msg[1])
@@ -87,7 +111,7 @@ def get_free_port(dispatcher_config):
     port = None
     with contextlib.suppress(KeyError, TypeError):
         dcport = dispatcher_config["nbd_server_port"]
-        if 'auto' in dcport:
+        if "auto" in dcport:
             pass
         elif dcport.isdigit():
             return dcport
@@ -108,3 +132,40 @@ def get_free_port(dispatcher_config):
             return port
     # fallthrough single default nbd port as per services file
     return 10809
+
+
+def requests_retry():
+    session = requests.Session()
+    # Retry 15 times over a period a bit longer than 10 minutes.
+    retries = 15
+    backoff_factor = 0.1
+    status_forcelist = [
+        # See https://en.wikipedia.org/wiki/List_of_HTTP_status_codes
+        408,  # Request Timeout
+        413,  # Payload Too Large
+        425,  # Too Early
+        429,  # Too Many Requests
+        500,  # Internal Server Error
+        502,  # Bad Gateway
+        503,  # Service Unavailable
+        504,  # Gateway Timeout
+        507,  # Insufficient Storage
+        # Unofficial codes
+        420,  # Enhance Your Calm
+        430,  # Request Header Fields Too Large
+        509,  # Bandwidth Limit Exceeded
+        529,  # Site is overloaded
+        598,  # (Informal convention) Network read timeout error
+    ]
+    retry = Retry(
+        total=retries,
+        read=retries,
+        connect=retries,
+        status=retries,
+        status_forcelist=status_forcelist,
+        backoff_factor=backoff_factor,
+    )
+    adapter = HTTPAdapter(max_retries=retry)
+    session.mount("http://", adapter)
+    session.mount("https://", adapter)
+    return session
