@@ -14,13 +14,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import argparse
-import logging
 import os
+import shlex
 import subprocess
-import syslog
+import sys
+import time
 
 from lava_common.constants import UDEV_RULE_FILENAME
-from lava_common.log import YAMLLogger
 
 from lava_dispatcher_host import add_device_container_mapping
 from lava_dispatcher_host import remove_device_container_mappings
@@ -28,51 +28,6 @@ from lava_dispatcher_host import share_device_with_container
 from lava_dispatcher_host.udev import get_udev_rules
 
 
-logger = None
-LINGER = 10000
-
-
-def setup_logger(data):
-    options = argparse.Namespace(**data)
-
-    # Pipeline always log as YAML so change the base logger.
-    # Every calls to logging.getLogger will now return a YAMLLogger
-    logging.setLoggerClass(YAMLLogger)
-
-    # The logger can be used by the parser and the Job object in all phases.
-    global logger
-    logger = logging.getLogger("dispatcher")
-    if options.logging_url is not None:
-        if options.master_cert and options.slave_cert:
-            if not os.path.exists(options.master_cert) or not os.path.exists(
-                options.slave_cert
-            ):
-                syslog.syslog(
-                    "[%s] Unable to find certificates for %s"
-                    % (options.job_id, options.logging_url)
-                )
-                return None
-        # pylint: disable=no-member
-        handler = logger.addZMQHandler(
-            options.logging_url,
-            options.master_cert,
-            options.slave_cert,
-            options.job_id,
-            options.socks_proxy,
-            options.ipv6,
-        )
-    else:
-        syslog.syslog("[%s] Logging to streamhandler" % options.job_id)
-        logger.addHandler(logging.StreamHandler())
-
-    return logger
-
-
-def finish_logger():
-    if logger:
-        logger.close(linger=LINGER)
-
-
 def handle_rules_show(options):
     print(get_udev_rules())
 
@@ -97,15 +52,14 @@ def handle_rules_install(options):
 
 
 def handle_devices_share(options):
-    share_device_with_container(options, setup_logger)
-    finish_logger()
+    share_device_with_container(options)
 
 
 def handle_devices_map(options):
     container = options.container
     container_type = options.container_type
     job_id = "0"  # fake map
-    fields = ["serial_number", "vendor_id", "product_id", "fs_label"]
+    fields = ["serial_number", "usb_vendor_id", "usb_product_id", "fs_label"]
     device_info = {
         k: options.__dict__[k] for k in fields if k in options and options.__dict__[k]
     }
@@ -169,10 +123,16 @@ def main(argv):
             default=None,
         )
         subparser.add_argument(
-            "--vendor-id", help="Vendor ID of the device to be shared", default=None
+            "--vendor-id",
+            dest="usb_vendor_id",
+            help="Vendor ID of the device to be shared",
+            default=None,
         )
         subparser.add_argument(
-            "--product-id", help="Product ID of the device to be shared", default=None
+            "--product-id",
+            dest="usb_product_id",
+            help="Product ID of the device to be shared",
+            default=None,
         )
         subparser.add_argument(
             "--fs-label",
@@ -192,7 +152,11 @@ def main(argv):
 
     if options.func:
         if options.debug_log:
-            options.debug_log.write("Called with args %r\n" % argv)
+            if not sys.stderr.isatty():
+                sys.stderr = options.debug_log
+            timestamp = time.strftime("%c", time.gmtime())
+            cmd = " ".join([shlex.quote(a) for a in argv])
+            options.debug_log.write("%s Called with: %s\n" % (timestamp, cmd))
         options.func(options)
         if options.debug_log:
             options.debug_log.close()
