@@ -27,7 +27,7 @@ from urllib.parse import quote
 
 from collections import OrderedDict  # pylint: disable=unused-import
 
-from lava_common.compat import yaml_load, yaml_safe_load
+from lava_common.compat import yaml_dump, yaml_load, yaml_safe_load
 from lava_common.version import __version__
 from lava_results_app.models import (
     TestSuite,
@@ -40,13 +40,6 @@ from lava_results_app.models import (
 from lava_common.timeout import Timeout
 
 
-def yaml_decimal_str(dumper, value):
-    return yaml.ScalarNode(tag=u"tag:yaml.org,2002:str", value=str(value))
-
-
-yaml.add_representer(decimal.Decimal, yaml_decimal_str)
-
-
 def _check_for_testset(result_dict, suite):
     """
     The presence of the test_set key indicates the start and usage of a TestSet.
@@ -99,7 +92,7 @@ def create_metadata_store(results, job):
         data = results["extra"]
     try:
         with open(meta_filename, "w") as extra_store:
-            yaml.dump(data, extra_store)
+            yaml_dump(data, extra_store)
     except OSError as exc:  # LAVA-847
         msg = "[%d] Unable to create metadata store: %s" % (job.id, exc)
         logger.error(msg)
@@ -108,7 +101,7 @@ def create_metadata_store(results, job):
     return meta_filename
 
 
-def map_scanned_results(results, job, markers, meta_filename):
+def map_scanned_results(results, job, starttc, endtc, meta_filename):
     """
     Sanity checker on the logged results dictionary
     :param results: results logged via the slave
@@ -132,7 +125,7 @@ def map_scanned_results(results, job, markers, meta_filename):
     if "extra" in results:
         results["extra"] = meta_filename
 
-    metadata = yaml.dump(results)
+    metadata = yaml_dump(results)
     if len(metadata) > 4096:  # bug 2471 - test_length unit test
         msg = "[%d] Result metadata is too long. %s" % (job.id, metadata)
         logger.warning(msg)
@@ -188,13 +181,6 @@ def map_scanned_results(results, job, markers, meta_filename):
                 name,
             )
             return None
-        # Add the marker if available
-        starttc = endtc = None
-        if name in markers:
-            test_case = markers[name].get("test_case")
-            starttc = markers[name].get("start_test_case", test_case)
-            endtc = markers[name].get("end_test_case", test_case)
-            del markers[name]
         try:
             test_case = TestCase(
                 name=name,
