@@ -17,12 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
-import sys
 from django.core.management.base import BaseCommand
-from lava_results_app.models import (
-    Query,
-    QueryMaterializedView
-)
+from lava_results_app.models import Query, QueryMaterializedView
 
 
 class Command(BaseCommand):
