@@ -35,7 +35,6 @@ import yaml
 import contextlib
 
 from django.conf import settings
-from django.contrib.admin.models import LogEntry, ADDITION
 from django.contrib.auth.models import User, Group
 from django.contrib.contenttypes import fields
 from django.contrib.contenttypes.models import ContentType
@@ -158,30 +157,6 @@ class QueryMaterializedView(MaterializedView):
         return QueryMaterializedView.objects.all()
 
 
-class BugLink(models.Model):
-    class Meta:
-        unique_together = ("object_id", "url", "content_type")
-
-    url = models.URLField(
-        max_length=1024, blank=False, null=False, verbose_name=_(u"Bug Link URL")
-    )
-
-    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
-    object_id = models.PositiveIntegerField()
-    content_object = fields.GenericForeignKey("content_type", "object_id")
-
-    def log_admin_entry(self, user, reason):
-        buglink_ct = ContentType.objects.get_for_model(BugLink)
-        LogEntry.objects.log_action(
-            user_id=user.id,
-            content_type_id=buglink_ct.pk,
-            object_id=self.pk,
-            object_repr=str(self),
-            action_flag=ADDITION,
-            change_message=reason,
-        )
-
-
 @nottest
 class TestSuite(models.Model, Queryable):
     """
@@ -420,8 +395,6 @@ class TestCase(models.Model, Queryable):
 
     logged = models.DateTimeField(auto_now=True)
 
-    buglinks = fields.GenericRelation(BugLink)
-
     @property
     def action_metadata(self):
         if not self.metadata:
@@ -846,7 +819,7 @@ class Query(models.Model):
         return QueryMaterializedView.view_exists(self.id)
 
     def get_results(self, user, order_by=["-id"]):
-        """ Used to get query results for persistant queries. """
+        """ Used to get query results for persistent queries. """
 
         omitted_list = QueryOmitResult.objects.filter(query=self).values_list(
             "object_id", flat=True
