@@ -30,31 +30,17 @@ from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import Group
 from django.core import serializers
-from django.core.exceptions import (
-    PermissionDenied,
-    FieldDoesNotExist,
-    FieldError
-)
-from django.core.urlresolvers import reverse
-from django.http import (
-    Http404,
-    HttpResponse,
-    HttpResponseRedirect
-)
+from django.core.exceptions import PermissionDenied, FieldDoesNotExist, FieldError
+from django.urls import reverse
+from django.http import Http404, HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404, loader
 from django.template import defaultfilters
 
-from lava_server.bread_crumbs import (
-    BreadCrumb,
-    BreadCrumbTrail,
-)
+from lava_server.bread_crumbs import BreadCrumb, BreadCrumbTrail
 
 from lava_results_app.views import index
 from lava_results_app.views.query.decorators import ownership_required
-from lava_results_app.views.query.forms import (
-    QueryForm,
-    QueryConditionForm,
-)
+from lava_results_app.views.query.forms import QueryForm, QueryConditionForm
 
 from lava_results_app.models import (
     Query,
@@ -65,7 +51,7 @@ from lava_results_app.models import (
     TestCase,
     TestSuite,
     InvalidConditionsError,
-    InvalidContentTypeError
+    InvalidContentTypeError,
 )
 
 from lava_results_app.views.query.tables import (
@@ -79,12 +65,9 @@ from lava_results_app.views.query.tables import (
 
 from lava_scheduler_app.models import TestJob
 
-from django.contrib.contenttypes.models import ContentType
-from django_tables2 import (
-    RequestConfig,
-)
+from django_tables2 import RequestConfig
 
-from lava.utils.lavatable import LavaView
+from lava_server.lavatable import LavaView
 
 
 class QueryViewDoesNotExistError(Exception):
@@ -92,40 +75,39 @@ class QueryViewDoesNotExistError(Exception):
 
 
 class UserQueryView(LavaView):
-
     def get_queryset(self):
         return Query.objects.filter(
-            is_archived=False,
-            owner__id=self.request.user.id).order_by('name')
+            is_archived=False, owner__id=self.request.user.id
+        ).order_by("name")
 
 
 class OtherQueryView(LavaView):
-
     def get_queryset(self):
         # All published queries which are not part
         # of any group.
-        other_queries = Query.objects.filter(
-            is_archived=False,
-            is_published=True,
-            query_group=None).exclude(
-                owner__id=self.request.user.id).order_by('name')
+        other_queries = (
+            Query.objects.filter(is_archived=False, is_published=True, query_group=None)
+            .exclude(owner__id=self.request.user.id)
+            .order_by("name")
+        )
 
         return other_queries
 
 
 class GroupQueryView(LavaView):
-
     def __init__(self, request, group, **kwargs):
         super().__init__(request, **kwargs)
         self.query_group = group
 
     def get_queryset(self):
         # Specific group queries.
-        group_queries = Query.objects.filter(
-            is_archived=False,
-            is_published=True,
-            query_group=self.query_group).exclude(
-                owner__id=self.request.user.id).order_by('name')
+        group_queries = (
+            Query.objects.filter(
+                is_archived=False, is_published=True, query_group=self.query_group
+            )
+            .exclude(owner__id=self.request.user.id)
+            .order_by("name")
+        )
 
         return group_queries
 
@@ -138,23 +120,19 @@ QUERY_CONTENT_TYPE_TABLE = {
 
 
 class QueryCustomResultView(LavaView):
-
-    def __init__(self, content_type, conditions,
-                 request, **kwargs):
+    def __init__(self, content_type, conditions, request, **kwargs):
         self.content_type = content_type
         self.conditions = conditions
         self.request = request
         super().__init__(request, **kwargs)
 
     def get_queryset(self):
-        return Query.get_queryset(
-            self.content_type,
-            self.conditions).visible_by_user(
-                self.request.user)
+        return Query.get_queryset(self.content_type, self.conditions).visible_by_user(
+            self.request.user
+        )
 
 
 class QueryResultView(LavaView):
-
     def __init__(self, query, request, **kwargs):
         self.query = query
         self.request = request
@@ -172,25 +150,25 @@ def query_list(request):
     for group in QueryGroup.objects.all():
         if group.query_set.count():
             prefix = "group_%s_" % group.id
-            group_view = GroupQueryView(request, group, model=Query,
-                                        table_class=GroupQueryTable)
-            table = GroupQueryTable(group_view.get_table_data(prefix),
-                                    prefix=prefix)
+            group_view = GroupQueryView(
+                request, group, model=Query, table_class=GroupQueryTable
+            )
+            table = GroupQueryTable(
+                group_view.get_table_data(prefix), request=request, prefix=prefix
+            )
             search_data.update(table.prepare_search_data(group_view))
             discrete_data.update(table.prepare_discrete_data(group_view))
             terms_data.update(table.prepare_terms_data(group_view))
             group_tables[group.name] = table
-            config = RequestConfig(request,
-                                   paginate={"per_page": table.length})
+            config = RequestConfig(request, paginate={"per_page": table.length})
             config.configure(table)
 
     prefix = "other_"
-    other_view = OtherQueryView(request, model=Query,
-                                table_class=OtherQueryTable)
-    other_query_table = OtherQueryTable(other_view.get_table_data(prefix),
-                                        prefix=prefix)
-    config = RequestConfig(request,
-                           paginate={"per_page": other_query_table.length})
+    other_view = OtherQueryView(request, model=Query, table_class=OtherQueryTable)
+    other_query_table = OtherQueryTable(
+        other_view.get_table_data(prefix), request=request, prefix=prefix
+    )
+    config = RequestConfig(request, paginate={"per_page": other_query_table.length})
     config.configure(other_query_table)
     search_data.update(other_query_table.prepare_search_data(other_view))
     discrete_data.update(other_query_table.prepare_discrete_data(other_view))
@@ -198,32 +176,34 @@ def query_list(request):
 
     prefix = "user_"
     view = UserQueryView(request, model=Query, table_class=UserQueryTable)
-    user_query_table = UserQueryTable(view.get_table_data(prefix),
-                                      prefix=prefix)
-    config = RequestConfig(request,
-                           paginate={"per_page": user_query_table.length})
+    user_query_table = UserQueryTable(
+        view.get_table_data(prefix), request=request, prefix=prefix
+    )
+    config = RequestConfig(request, paginate={"per_page": user_query_table.length})
     config.configure(user_query_table)
     search_data.update(user_query_table.prepare_search_data(view))
     discrete_data.update(user_query_table.prepare_discrete_data(view))
     terms_data.update(user_query_table.prepare_terms_data(view))
 
-    template = loader.get_template('lava_results_app/query_list.html')
-    return HttpResponse(template.render(
-        {
-            'user_query_table': user_query_table,
-            'other_query_table': other_query_table,
-            'search_data': search_data,
-            "discrete_data": discrete_data,
-            'terms_data': terms_data,
-            'group_tables': group_tables,
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(query_list),
-            'context_help': ['lava-queries-charts'],
-        }, request=request)
+    template = loader.get_template("lava_results_app/query_list.html")
+    return HttpResponse(
+        template.render(
+            {
+                "user_query_table": user_query_table,
+                "other_query_table": other_query_table,
+                "search_data": search_data,
+                "discrete_data": discrete_data,
+                "terms_data": terms_data,
+                "group_tables": group_tables,
+                "bread_crumb_trail": BreadCrumbTrail.leading_to(query_list),
+                "context_help": ["lava-queries-charts"],
+            },
+            request=request,
+        )
     )
 
 
-@BreadCrumb("Query ~{username}/{name}", parent=query_list,
-            needs=['username', 'name'])
+@BreadCrumb("Query ~{username}/{name}", parent=query_list, needs=["username", "name"])
 def query_display(request, username, name):
 
     query = get_object_or_404(Query, owner__username=username, name=name)
@@ -236,13 +216,11 @@ def query_display(request, username, name):
         query=query,
         request=request,
         model=query.content_type.model_class(),
-        table_class=QUERY_CONTENT_TYPE_TABLE[query.content_type.model_class()]
+        table_class=QUERY_CONTENT_TYPE_TABLE[query.content_type.model_class()],
     )
 
     table = QUERY_CONTENT_TYPE_TABLE[query.content_type.model_class()](
-        query,
-        request.user,
-        view.get_table_data()
+        query, request.user, view.get_table_data()
     )
 
     try:
@@ -251,25 +229,33 @@ def query_display(request, username, name):
     except ProgrammingError:
         raise QueryViewDoesNotExistError(
             "Query view does not exist. Please contact query owner or system "
-            "administrator.")
+            "administrator."
+        )
 
-    omitted = [result.content_object for result in QueryOmitResult.objects.filter(query=query)]
-    template = loader.get_template('lava_results_app/query_display.html')
-    return HttpResponse(template.render(
-        {
-            'query': query,
-            'entity': query.content_type.model,
-            'conditions': Query.serialize_conditions(
-                query.querycondition_set.all()),
-            'omitted': omitted,
-            'query_table': table,
-            'terms_data': table.prepare_terms_data(view),
-            'search_data': table.prepare_search_data(view),
-            'discrete_data': table.prepare_discrete_data(view),
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                query_display, username=username, name=name),
-            'context_help': ['lava-queries-charts'],
-        }, request=request)
+    omitted = [
+        result.content_object for result in QueryOmitResult.objects.filter(query=query)
+    ]
+    template = loader.get_template("lava_results_app/query_display.html")
+    return HttpResponse(
+        template.render(
+            {
+                "query": query,
+                "entity": query.content_type.model,
+                "conditions": Query.serialize_conditions(
+                    query.querycondition_set.all()
+                ),
+                "omitted": omitted,
+                "query_table": table,
+                "terms_data": table.prepare_terms_data(view),
+                "search_data": table.prepare_search_data(view),
+                "discrete_data": table.prepare_discrete_data(view),
+                "bread_crumb_trail": BreadCrumbTrail.leading_to(
+                    query_display, username=username, name=name
+                ),
+                "context_help": ["lava-queries-charts"],
+            },
+            request=request,
+        )
     )
 
 
@@ -285,13 +271,12 @@ def query_custom(request):
 
     if content_type.model_class() not in QueryCondition.RELATION_MAP:
         messages.error(
-            request,
-            "Wrong table name in entity param. Please refer to query docs.")
+            request, "Wrong table name in entity param. Please refer to query docs."
+        )
         raise Http404()
 
     try:
-        conditions = Query.parse_conditions(content_type,
-                                            request.GET.get("conditions"))
+        conditions = Query.parse_conditions(content_type, request.GET.get("conditions"))
     except InvalidConditionsError as e:
         messages.error(request, e)
         raise Http404()
@@ -301,14 +286,12 @@ def query_custom(request):
         conditions=conditions,
         request=request,
         model=content_type.model_class(),
-        table_class=QUERY_CONTENT_TYPE_TABLE[content_type.model_class()]
+        table_class=QUERY_CONTENT_TYPE_TABLE[content_type.model_class()],
     )
 
     try:
         table = QUERY_CONTENT_TYPE_TABLE[content_type.model_class()](
-            None,
-            request.user,
-            view.get_table_data()
+            None, request.user, view.get_table_data()
         )
     except (FieldDoesNotExist, FieldError) as e:
         messages.error(request, e)
@@ -316,41 +299,45 @@ def query_custom(request):
 
     config = RequestConfig(request, paginate={"per_page": table.length})
     config.configure(table)
-    template = loader.get_template('lava_results_app/query_custom.html')
-    return HttpResponse(template.render(
-        {
-            'query_table': table,
-            'conditions': conditions,
-            'terms_data': table.prepare_terms_data(view),
-            'search_data': table.prepare_search_data(view),
-            'discrete_data': table.prepare_discrete_data(view),
-
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(query_custom),
-            'context_help': ['lava-queries-charts'],
-        }, request=request)
+    template = loader.get_template("lava_results_app/query_custom.html")
+    return HttpResponse(
+        template.render(
+            {
+                "query_table": table,
+                "conditions": conditions,
+                "terms_data": table.prepare_terms_data(view),
+                "search_data": table.prepare_search_data(view),
+                "discrete_data": table.prepare_discrete_data(view),
+                "bread_crumb_trail": BreadCrumbTrail.leading_to(query_custom),
+                "context_help": ["lava-queries-charts"],
+            },
+            request=request,
+        )
     )
 
 
-@BreadCrumb("Query ~{username}/{name}", parent=query_list,
-            needs=['username', 'name'])
+@BreadCrumb("Query ~{username}/{name}", parent=query_list, needs=["username", "name"])
 @login_required
 def query_detail(request, username, name):
 
     query = get_object_or_404(Query, owner__username=username, name=name)
-    query_conditions = Query.serialize_conditions(
-        query.querycondition_set.all())
-    template = loader.get_template('lava_results_app/query_detail.html')
-    return HttpResponse(template.render(
-        {
-            'query': query,
-            'query_conditions': query_conditions,
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                query_detail, username=username, name=name),
-            'context_help': ['lava-queries-charts'],
-            'condition_form': QueryConditionForm(
-                instance=None,
-                initial={'query': query, 'table': query.content_type}),
-        }, request=request)
+    query_conditions = Query.serialize_conditions(query.querycondition_set.all())
+    template = loader.get_template("lava_results_app/query_detail.html")
+    return HttpResponse(
+        template.render(
+            {
+                "query": query,
+                "query_conditions": query_conditions,
+                "bread_crumb_trail": BreadCrumbTrail.leading_to(
+                    query_detail, username=username, name=name
+                ),
+                "context_help": ["lava-queries-charts"],
+                "condition_form": QueryConditionForm(
+                    instance=None, initial={"query": query, "table": query.content_type}
+                ),
+            },
+            request=request,
+        )
     )
 
 
@@ -364,14 +351,10 @@ def query_add(request):
     if request.GET.get("entity"):
         query.content_type = Query.get_content_type(request.GET.get("entity"))
 
-    return query_form(
-        request,
-        BreadCrumbTrail.leading_to(query_add),
-        instance=query)
+    return query_form(request, BreadCrumbTrail.leading_to(query_add), instance=query)
 
 
-@BreadCrumb("Edit ~{username}/{name}", parent=query_detail,
-            needs=['username', 'name'])
+@BreadCrumb("Edit ~{username}/{name}", parent=query_detail, needs=["username", "name"])
 @login_required
 @ownership_required
 def query_edit(request, username, name):
@@ -381,7 +364,8 @@ def query_edit(request, username, name):
     return query_form(
         request,
         BreadCrumbTrail.leading_to(query_edit, username=username, name=name),
-        instance=query)
+        instance=query,
+    )
 
 
 @login_required
@@ -391,8 +375,7 @@ def query_delete(request, username, name):
     query = get_object_or_404(Query, owner__username=username, name=name)
     query.is_archived = True
     query.save()
-    return HttpResponseRedirect(reverse(
-        'lava.results.query_list'))
+    return HttpResponseRedirect(reverse("lava.results.query_list"))
 
 
 @login_required
@@ -421,13 +404,12 @@ def query_export_custom(request):
 
     if content_type.model_class() not in QueryCondition.RELATION_MAP:
         messages.error(
-            request,
-            "Wrong table name in entity param. Please refer to query docs.")
+            request, "Wrong table name in entity param. Please refer to query docs."
+        )
         raise Http404()
 
     try:
-        conditions = Query.parse_conditions(
-            content_type, request.GET.get("conditions"))
+        conditions = Query.parse_conditions(content_type, request.GET.get("conditions"))
     except InvalidConditionsError as e:
         messages.error(request, e)
         raise Http404()
@@ -436,7 +418,8 @@ def query_export_custom(request):
 
     try:
         results = Query.get_queryset(content_type, conditions).visible_by_user(
-            request.user)
+            request.user
+        )
     except (FieldDoesNotExist, FieldError) as e:
         messages.error(request, e)
         raise Http404()
@@ -456,7 +439,7 @@ def query_toggle_published(request, username, name):
     return HttpResponseRedirect(query.get_absolute_url() + "/+detail")
 
 
-@BreadCrumb("Copy", parent=query_detail, needs=['username', 'name'])
+@BreadCrumb("Copy", parent=query_detail, needs=["username", "name"])
 @login_required
 def query_copy(request, username, name):
     query = get_object_or_404(Query, owner__username=username, name=name)
@@ -467,7 +450,8 @@ def query_copy(request, username, name):
         request,
         BreadCrumbTrail.leading_to(query_copy, name=name, username=username),
         instance=query,
-        is_copy=True)
+        is_copy=True,
+    )
 
 
 @login_required
@@ -488,25 +472,26 @@ def query_refresh(request, name, username):
         error_msg = "%s<br>Please contact system administrator." % str(e)
 
     last_updated = defaultfilters.date(query.last_updated, "DATETIME_FORMAT")
-    return HttpResponse(simplejson.dumps([success, str(last_updated),
-                                          error_msg]),
-                        content_type='application/json')
+    return HttpResponse(
+        simplejson.dumps([success, str(last_updated), error_msg]),
+        content_type="application/json",
+    )
 
 
 @login_required
 def query_group_list(request):
 
-    term = request.GET['term']
-    groups = [str(group.name) for group in QueryGroup.objects.filter(
-        name__istartswith=term)]
-    return HttpResponse(simplejson.dumps(groups),
-                        content_type='application/json')
+    term = request.GET["term"]
+    groups = [
+        str(group.name) for group in QueryGroup.objects.filter(name__istartswith=term)
+    ]
+    return HttpResponse(simplejson.dumps(groups), content_type="application/json")
 
 
 @login_required
 def query_add_group(request, username, name):
 
-    if request.method != 'POST':
+    if request.method != "POST":
         raise PermissionDenied
 
     group_name = request.POST.get("value")
@@ -532,7 +517,7 @@ def query_add_group(request, username, name):
 @ownership_required
 def query_select_group(request, username, name):
 
-    if request.method != 'POST':
+    if request.method != "POST":
         raise PermissionDenied
 
     group_name = request.POST.get("value")
@@ -555,16 +540,11 @@ def query_select_group(request, username, name):
 @login_required
 def get_query_group_names(request):
 
-    term = request.GET['term']
+    term = request.GET["term"]
     groups = []
-    for group in Group.objects.filter(user=request.user,
-                                      name__istartswith=term):
-        groups.append(
-            {"id": group.id,
-             "name": group.name,
-             "label": group.name})
-    return HttpResponse(simplejson.dumps(groups),
-                        content_type='application/json')
+    for group in Group.objects.filter(user=request.user, name__istartswith=term):
+        groups.append({"id": group.id, "name": group.name, "label": group.name})
+    return HttpResponse(simplejson.dumps(groups), content_type="application/json")
 
 
 @login_required
@@ -573,9 +553,7 @@ def query_add_condition(request, username, name):
 
     query = get_object_or_404(Query, owner__username=username, name=name)
 
-    return query_condition_form(
-        request, query,
-        BreadCrumbTrail.leading_to(query_add))
+    return query_condition_form(request, query, BreadCrumbTrail.leading_to(query_add))
 
 
 @login_required
@@ -586,9 +564,8 @@ def query_edit_condition(request, username, name, id):
     query_condition = get_object_or_404(QueryCondition, id=id)
 
     return query_condition_form(
-        request, query,
-        BreadCrumbTrail.leading_to(query_add),
-        instance=query_condition)
+        request, query, BreadCrumbTrail.leading_to(query_add), instance=query_condition
+    )
 
 
 @login_required
@@ -610,8 +587,7 @@ def query_omit_result(request, username, name, id):
     result_object = get_object_or_404(query.content_type.model_class(), id=id)
 
     try:
-        QueryOmitResult.objects.create(query=query,
-                                       content_object=result_object)
+        QueryOmitResult.objects.create(query=query, content_object=result_object)
     except IntegrityError:
         # Ignore unique constraint violation.
         pass
@@ -628,9 +604,8 @@ def query_include_result(request, username, name, id):
 
     try:
         QueryOmitResult.objects.get(
-            query=query,
-            object_id=result_object.id,
-            content_type=query.content_type).delete()
+            query=query, object_id=result_object.id, content_type=query.content_type
+        ).delete()
     except QueryOmitResult.DoesNotExist:
         # Ignore does not exist violation.
         raise
@@ -640,34 +615,40 @@ def query_include_result(request, username, name, id):
 
 def get_query_names(request):
 
-    term = request.GET['term']
+    term = request.GET["term"]
     result = []
 
-    query_list = Query.objects.filter(
-        Q(is_archived=False),
-        Q(name__istartswith=term) |
-        Q(owner__username__istartswith=term)).distinct().order_by('name')
+    query_list = (
+        Query.objects.filter(
+            Q(is_archived=False),
+            Q(name__istartswith=term) | Q(owner__username__istartswith=term),
+        )
+        .distinct()
+        .order_by("name")
+    )
     for query in query_list:
-        result.append({"value": query.owner_name,
-                       "label": query.owner_name,
-                       "id": query.id,
-                       "content_type": query.content_type.model_class().__name__})
-    return HttpResponse(
-        simplejson.dumps(list(result)),
-        content_type='application/json')
+        result.append(
+            {
+                "value": query.owner_name,
+                "label": query.owner_name,
+                "id": query.id,
+                "content_type": query.content_type.model_class().__name__,
+            }
+        )
+    return HttpResponse(simplejson.dumps(list(result)), content_type="application/json")
 
 
 def query_form(request, bread_crumb_trail, instance=None, is_copy=False):
 
-    if request.method == 'POST':
+    if request.method == "POST":
 
-        form = QueryForm(request.user, request.POST,
-                         instance=instance, is_copy=is_copy)
+        form = QueryForm(request.user, request.POST, instance=instance, is_copy=is_copy)
         if form.is_valid():
             query = form.save()
             if request.GET.get("conditions"):
                 conditions = Query.parse_conditions(
-                    query.content_type, request.GET.get("conditions"))
+                    query.content_type, request.GET.get("conditions")
+                )
                 for condition in conditions:
                     condition.query = query
                     condition.save()
@@ -676,25 +657,28 @@ def query_form(request, bread_crumb_trail, instance=None, is_copy=False):
 
     else:
         form = QueryForm(request.user, instance=instance, is_copy=is_copy)
-        form.fields['owner'].initial = request.user
+        form.fields["owner"].initial = request.user
 
     query_name = None
     if is_copy:
         query_name = instance.name
         instance.name = None
-    template = loader.get_template('lava_results_app/query_form.html')
-    return HttpResponse(template.render(
-        {
-            'bread_crumb_trail': bread_crumb_trail,
-            'is_copy': is_copy,
-            'query_name': query_name,
-            'form': form,
-            'context_help': ['lava-queries-charts'],
-        }, request=request))
+    template = loader.get_template("lava_results_app/query_form.html")
+    return HttpResponse(
+        template.render(
+            {
+                "bread_crumb_trail": bread_crumb_trail,
+                "is_copy": is_copy,
+                "query_name": query_name,
+                "form": form,
+                "context_help": ["lava-queries-charts"],
+            },
+            request=request,
+        )
+    )
 
 
-def query_condition_form(request, query,
-                         bread_crumb_trail, instance=None):
+def query_condition_form(request, query, bread_crumb_trail, instance=None):
 
     form = QueryConditionForm(request.POST, instance=instance)
 
@@ -702,12 +686,13 @@ def query_condition_form(request, query,
         query_condition = form.save()
 
         return HttpResponse(
-            serializers.serialize(
-                "json", [query_condition, query_condition.table]),
-            content_type='application/json')
+            serializers.serialize("json", [query_condition, query_condition.table]),
+            content_type="application/json",
+        )
     else:
-        return HttpResponse(simplejson.dumps(["fail", form.errors]),
-                            content_type='application/json')
+        return HttpResponse(
+            simplejson.dumps(["fail", form.errors]), content_type="application/json"
+        )
 
 
 def _remove_dir(path):
@@ -732,34 +717,55 @@ def _export_query(query_results, content_type, filename):
     # Remove non-relevant columns for CSV file.
     removed_fields = [
         # TestJob fields:
-        "user_id", "actual_device_id", "definition", "admin_notifications",
-        "group_id", "multinode_definition", "original_definition", "health_check",
-        "sub_id", "submitter_id", "testdata", "testsuite", "target_group",
-        "notification", "testjobmaterializedview", "testjobuser",
+        "user_id",
+        "actual_device_id",
+        "definition",
+        "group_id",
+        "multinode_definition",
+        "original_definition",
+        "health_check",
+        "sub_id",
+        "submitter_id",
+        "testdata",
+        "testsuite",
+        "target_group",
+        "notification",
+        "testjobmaterializedview",
+        "testjobuser",
         "pipeline_compatibility",
         # TestSuite fields:
         "job_id",
         # TestCase fields:
-        "actionlevels", "suite_id", "test_set_id"
+        "actionlevels",
+        "suite_id",
+        "test_set_id",
     ]
     for field in removed_fields:
         if field in query_keys:
             query_keys.remove(field)
 
-    with open(file_path, 'w+') as csv_file:
-        out = csv.DictWriter(csv_file, quoting=csv.QUOTE_ALL,
-                             extrasaction='ignore',
-                             fieldnames=query_keys)
+    with open(file_path, "w+") as csv_file:
+        out = csv.DictWriter(
+            csv_file,
+            quoting=csv.QUOTE_ALL,
+            extrasaction="ignore",
+            fieldnames=query_keys,
+        )
         out.writeheader()
 
         for result in query_results:
             result_dict = result.__dict__.copy()
             # Encode the strings if necessary.
-            out.writerow({k: (v.encode('utf8') if isinstance(v, str) else v) for k, v in result_dict.items()})
+            out.writerow(
+                {
+                    k: (v.encode("utf8") if isinstance(v, str) else v)
+                    for k, v in result_dict.items()
+                }
+            )
 
-    response = HttpResponse(content_type='text/csv')
-    response['Content-Disposition'] = "attachment; filename=%s.csv" % filename
-    with open(file_path, 'r') as csv_file:
+    response = HttpResponse(content_type="text/csv")
+    response["Content-Disposition"] = "attachment; filename=%s.csv" % filename
+    with open(file_path, "r") as csv_file:
         response.write(csv_file.read())
 
     _remove_dir(tmp_dir)
