@@ -22,10 +22,12 @@ import xmlrpc.client
 
 from django.core.exceptions import ValidationError
 from django.db import IntegrityError, transaction
+from django.db.models import Q, Prefetch
 
+from lava_common.compat import yaml_safe_load
 from linaro_django_xmlrpc.models import ExposedV2API
 from lava_scheduler_app.api import check_perm
-from lava_scheduler_app.models import Device, DeviceType, Tag, Worker
+from lava_scheduler_app.models import Device, DeviceType, Tag, TestJob, Worker
 
 
 class SchedulerDevicesAPI(ExposedV2API):
@@ -150,7 +152,7 @@ class SchedulerDevicesAPI(ExposedV2API):
         job_ctx = None
         if context is not None:
             try:
-                job_ctx = yaml.safe_load(context)
+                job_ctx = yaml_safe_load(context)
             except yaml.YAMLError as exc:
                 raise xmlrpc.client.Fault(
                     400, "Job Context '%s' is not valid: %s" % (context, str(exc))
@@ -229,6 +231,13 @@ class SchedulerDevicesAPI(ExposedV2API):
             Device.objects.all()
             .visible_by_user(self.user)
             .select_related("device_type")
+            .prefetch_related(
+                Prefetch(
+                    "testjobs",
+                    queryset=TestJob.objects.filter(~Q(state=TestJob.STATE_FINISHED)),
+                    to_attr="running_jobs",
+                )
+            )
         )
         if not show_all:
             devices = devices.exclude(health=Device.HEALTH_RETIRED)
@@ -269,7 +278,9 @@ class SchedulerDevicesAPI(ExposedV2API):
         This function returns an XML-RPC dictionary with device details
         """
         try:
-            device = Device.objects.get(hostname=hostname)
+            device = Device.objects.select_related("device_type", "worker_host").get(
+                hostname=hostname
+            )
         except Device.DoesNotExist:
             raise xmlrpc.client.Fault(404, "Device '%s' was not found." % hostname)
 
