@@ -217,10 +217,9 @@ def find_our_daemons():
     """
     daemons = {
         "lava-server-gunicorn": None,
-        "lava-master": None,
-        "lava-logs": None,
         "lava-publisher": None,
-        "lava-slave": None,
+        "lava-scheduler": None,
+        "lava-worker": None,
     }
 
     for path in Path("/proc").glob("*/cmdline"):
@@ -247,16 +246,14 @@ def find_our_daemons():
         if "/usr/bin/lava-server" in content[1]:
             if "manage" not in content[2]:
                 continue
-            if "lava-master" in content[3]:
-                daemons["lava-master"] = pid
-            elif "lava-logs" in content[3]:
-                daemons["lava-logs"] = pid
-            elif "lava-publisher" in content[3]:
+            if "lava-publisher" in content[3]:
                 daemons["lava-publisher"] = pid
+            elif "lava-scheduler" in content[3]:
+                daemons["lava-scheduler"] = pid
             continue
 
-        if "/usr/bin/lava-slave" in content[1]:
-            daemons["lava-slave"] = pid
+        if "/usr/bin/lava-worker" in content[1]:
+            daemons["lava-worker"] = pid
             continue
 
     return daemons
@@ -269,18 +266,17 @@ def check_services(app_configs, **kwargs):
     services = [
         "apache2",
         "lava-server-gunicorn",
-        "lava-master",
         "lava-publisher",
-        "lava-logs",
+        "lava-scheduler",
         "postgresql",
     ]
-    optional = ["lava-slave"]
+    optional = ["lava-worker"]
 
     # check if systemd is running
     try:
         subprocess.check_output(["systemctl"], stderr=subprocess.PIPE)
         running_systemd = True
-    except subprocess.CalledProcessError:
+    except (FileNotFoundError, subprocess.CalledProcessError):
         running_systemd = False
 
     if running_systemd:
