@@ -78,6 +78,7 @@ def _deploy_tftp_schema():
             Optional("nfsrootfs"): {Required("url"): str},
             Optional("dtb"): {Required("url"): str},
             Optional("modules"): {Required("url"): str},
+            Optional("tee"): {Required("url"): str},
         },
         extra=True,
     )
@@ -217,6 +218,7 @@ def _interactive_script_schema():
                 Optional("lava-sync"): str,
                 Optional("lava-wait"): str,
                 Optional("lava-wait-all"): str,
+                Optional("wait_for_prompt"): bool,
                 Optional("failures"): [
                     {
                         Required("message"): str,
