@@ -27,17 +27,11 @@ import zmq
 from zmq.utils.strtypes import b
 
 from django.conf import settings
-from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
 from django.db.models.signals import post_init, post_save, pre_delete, pre_save
 
-from lava_common.compat import yaml_safe_load
 from lava_scheduler_app.models import Device, TestJob, Worker
-from lava_scheduler_app.notifications import (
-    create_notification,
-    notification_criteria,
-    send_notifications,
-)
+from lava_scheduler_app.tasks import async_send_notifications
 
 
 # Thread local storage for zmq socket and context
@@ -117,10 +111,13 @@ def device_post_handler(sender, **kwargs):
             "state": instance.get_state_display(),
             "device": instance.hostname,
             "device_type": instance.device_type.name,
+            "worker": None,
         }
         current_job = instance.current_job()
         if current_job is not None:
             data["job"] = current_job.display_id
+        if instance.worker_host is not None:
+            data["worker"] = instance.worker_host.hostname
 
         # Send the event
         send_event(".device", "lavaserver", data)
@@ -148,16 +145,7 @@ def testjob_notifications(sender, **kwargs):
     if job.state not in [TestJob.STATE_RUNNING, TestJob.STATE_FINISHED]:
         return
 
-    job_def = yaml_safe_load(job.definition)
-    if "notify" in job_def:
-        if notification_criteria(
-            job_def["notify"]["criteria"], job.state, job.health, job._old_health
-        ):
-            try:
-                job.notification
-            except ObjectDoesNotExist:
-                create_notification(job, job_def["notify"])
-            send_notifications(job)
+    async_send_notifications.delay(job.id, job.state, job.health, job._old_health)
 
 
 @log_exception
@@ -192,6 +180,8 @@ def testjob_post_handler(sender, **kwargs):
             data["sub_id"] = instance.sub_id
         if instance.actual_device:
             data["device"] = instance.actual_device.hostname
+            if instance.actual_device.worker_host:
+                data["worker"] = instance.actual_device.worker_host.hostname
         if instance.requested_device_type:
             data["device_type"] = instance.requested_device_type.name
         if instance.start_time:
@@ -264,7 +254,7 @@ pre_save.connect(
     dispatch_uid="testjob_notifications",
 )
 
-# Only activate theses signals when EVENT_NOTIFICATION is in use
+# Only activate these signals when EVENT_NOTIFICATION is in use
 if settings.EVENT_NOTIFICATION:
     post_init.connect(
         device_init_handler,
