@@ -18,18 +18,14 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
-import contextlib
-import os
-import pathlib
 import xmlrpc.client
-import yaml
 
 from django.http import Http404
 from django.conf import settings
 from django.contrib.auth.models import Group
 from django.core.exceptions import PermissionDenied
 
-from lava_common.compat import yaml_safe_dump, yaml_safe_load
+from lava_common.compat import yaml_safe_dump
 from lava_common.version import __version__
 from lava_scheduler_app.api import check_perm
 from lava_scheduler_app.views import get_restricted_job
@@ -145,54 +141,13 @@ class LavaSystemAPI(SystemAPI):
         ------------
         Returns a dictionary containing the following keys:
         {
-          "MASTER_URL": "tcp://<lava-master-dns>:5556",
-          "LOGGING_URL": "tcp://<lava-master-dns>:5555",
-          "ENCRYPT": False,
-          "IPv6": False,
           "EVENT_SOCKET": "tcp://*:5500",
           "EVENT_TOPIC": "org.linaro.validation",
           "EVENT_NOTIFICATION": True,
           "LOG_SIZE_LIMIT": 10,
         }
-
-        If ENCRYPT is True, clients MUST already have a usable
-        client certificate installed on the master AND the current
-        master certificate installed on the client, before a
-        connection can be made.
         """
-        data = {
-            "master_socket": "tcp://<lava-master-dns>:5556",
-            "socket": "tcp://<lava-master-dns>:5555",
-            "encrypt": False,
-            "ipv6": False,
-        }
-
-        master = {"ERROR": "invalid master config"}
-        filename = os.path.join(settings.MEDIA_ROOT, "lava-master-config.yaml")
-        if os.path.exists(filename):
-            try:
-                with open(filename, "r") as output:
-                    master = yaml_safe_load(output)
-            except yaml.YAMLError as exc:
-                return master
-        if master:
-            data.update(master)
-
-        log_config = {"ERROR": "invalid logging config"}
-        filename = os.path.join(settings.MEDIA_ROOT, "lava-logs-config.yaml")
-        if os.path.exists(filename):
-            try:
-                with open(filename, "r") as output:
-                    log_config = yaml_safe_load(output)
-            except yaml.YAMLError as exc:
-                return log_config
-        if log_config:
-            data.update(log_config)
         return {
-            "MASTER_URL": data["master_socket"],
-            "LOGGING_URL": data["socket"],
-            "IPv6": data["ipv6"],
-            "ENCRYPT": data.get("encrypt", False),
             "EVENT_TOPIC": settings.EVENT_TOPIC,
             "EVENT_SOCKET": settings.EVENT_SOCKET,
             "EVENT_NOTIFICATION": settings.EVENT_NOTIFICATION,
@@ -723,34 +678,6 @@ class LavaSystemAPI(SystemAPI):
 
         GroupDevicePermission.objects.remove_perm(perm, group, device)
 
-    def get_master_certificate(self):
-        """
-        Name
-        ----
-        `scheduler.system.get_master_certificate` ()
-
-        Description
-        -----------
-        Return the master public certificate found in location specified
-        in django settings.
-
-        Arguments
-        ---------
-        None
-
-        Return value
-        ------------
-        This function returns the public certificate found on master
-        """
-        self._authenticate()
-
-        path = pathlib.Path(settings.MASTER_CERT_PUB)
-        with contextlib.suppress(OSError):
-            data = path.read_text(encoding="utf-8")
-            return xmlrpc.client.Binary(data.encode("utf-8"))
-
-        raise xmlrpc.client.Fault(404, "Master does not have a certificate")
-
 
 class LavaMapper(Mapper):
     def register_introspection_methods(self):
