@@ -31,10 +31,18 @@ class Command(BaseCommand):
     help = "Move job outputs into the new location"
 
     def add_arguments(self, parser):
-        parser.add_argument("--dry-run", default=False, action="store_true",
-                            help="Do not move any data, simulate the output")
-        parser.add_argument("--slow", default=False, action="store_true",
-                            help="Be nice with the system by sleeping regularly")
+        parser.add_argument(
+            "--dry-run",
+            default=False,
+            action="store_true",
+            help="Do not move any data, simulate the output",
+        )
+        parser.add_argument(
+            "--slow",
+            default=False,
+            action="store_true",
+            help="Be nice with the system by sleeping regularly",
+        )
 
     def handle(self, *_, **options):
         base_dir = "/var/lib/lava-server/default/media/job-output/"
@@ -45,21 +53,27 @@ class Command(BaseCommand):
         start = 0
         while True:
             count = 0
-            for job in jobs[start:start + 100]:
+            for job in jobs[start : start + 100]:
                 count += 1
-                old_path = os.path.join(settings.MEDIA_ROOT, 'job-output', 'job-%s' % job.id)
-                date_path = os.path.join(settings.MEDIA_ROOT, 'job-output',
-                                         "%02d" % job.submit_time.year,
-                                         "%02d" % job.submit_time.month,
-                                         "%02d" % job.submit_time.day,
-                                         str(job.id))
+                old_path = os.path.join(
+                    settings.MEDIA_ROOT, "job-output", "job-%s" % job.id
+                )
+                date_path = os.path.join(
+                    settings.MEDIA_ROOT,
+                    "job-output",
+                    "%02d" % job.submit_time.year,
+                    "%02d" % job.submit_time.month,
+                    "%02d" % job.submit_time.day,
+                    str(job.id),
+                )
                 if not os.path.exists(old_path):
                     self.stdout.write("* %d skip" % job.id)
                     continue
 
-                self.stdout.write("* %d {%s => %s}" % (job.id,
-                                                       old_path[len_base_dir:],
-                                                       date_path[len_base_dir:]))
+                self.stdout.write(
+                    "* %d {%s => %s}"
+                    % (job.id, old_path[len_base_dir:], date_path[len_base_dir:])
+                )
                 if not options["dry_run"]:
                     mkdir(os.path.dirname(date_path))
                     if not os.path.exists(old_path):
