@@ -57,6 +57,7 @@ INSTALLED_APPS = [
     "django_tables2",
     "linaro_django_xmlrpc",
     "rest_framework",
+    "rest_framework.authtoken",
     "django_filters",
     "rest_framework_filters",
     # Add contrib
@@ -231,12 +232,6 @@ SENTRY_DSN = ""
 # Django debug toolbar
 USE_DEBUG_TOOLBAR = False
 
-# Encryption settings
-ENCRYPT = False
-MASTER_CERT = "/etc/lava-dispatcher/certificates.d/master.key_secret"
-MASTER_CERT_PUB = "/etc/lava-dispatcher/certificates.d/master.key"
-SLAVES_CERTS = "/etc/lava-dispatcher/certificates.d/"
-
 # Alternative logging database settings.
 MONGO_DB_URI = "mongodb://user:pass@localhost:27017/"
 MONGO_DB_DATABASE = "lava-logs"
@@ -248,6 +243,20 @@ ELASTICSEARCH_APIKEY = ""
 # Send notifications to worker admins after the master is upgraded.
 MASTER_UPGRADE_NOTIFY = False
 
+# Worker in the specific network will be allowed to auto register
+WORKER_AUTO_REGISTER = True
+WORKER_AUTO_REGISTER_NETMASK = ["127.0.0.0/8", "::1"]
+
+###################
+# Celerey setting #
+###################
+# Make celery optional.
+# Force task to be executed in the caller thread and not in a worker
+# When this is True, no need for either a broker or a worker, everything is local.
+# In order to use celery (with a worker), admins should set it to False.
+CELERY_TASK_ALWAYS_EAGER = True
+# CELERY_BROKER_URL = "redis://localhost:6379/0"
+
 ################
 # DRF settings #
 ################
