@@ -24,16 +24,14 @@ from django.db.backends.signals import connection_created
 
 
 # Set the environment variables for Django
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "lava_server.settings.distro")
-os.environ.setdefault("DJANGO_DEBIAN_SETTINGS_TEMPLATE",
-                      "/etc/lava-server/{filename}.conf")
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "lava_server.settings.prod")
 
 
 # Set the postgresql connection timeout
 # The timeout is only used when running through wsgi.  This way, command line
 # commands are not affected by the timeout.
 def setup_postgres(connection, **kwargs):
-    if connection.vendor != 'postgresql':
+    if connection.vendor != "postgresql":
         return
 
     with connection.cursor() as cursor:
