@@ -62,7 +62,7 @@ def run(cmd_list, failure_msg, stdin=None):
     return ret
 
 
-def database(config):
+def create_database(config):
     db = config["DATABASES"]["default"]["NAME"]
     password = config["DATABASES"]["default"]["PASSWORD"]
     user = config["DATABASES"]["default"]["USER"]
@@ -70,6 +70,13 @@ def database(config):
     devel_password = "devel"
     devel_user = "devel"
 
+    # is the database ready?
+    try:
+        subprocess.check_call(["pg_isready"])
+    except subprocess.CalledProcessError:
+        print("Skipping database creation as PostgreSQL is not running")
+        return
+
     script = f"""
 DO $$
 BEGIN
@@ -104,6 +111,8 @@ WHERE NOT EXISTS (SELECT FROM pg_database WHERE datname = '{devel_db}')\\gexec
         uid = pwd.getpwnam("root")[2]
         os.seteuid(uid)
 
+
+def update_database():
     run(
         ["lava-server", "manage", "migrate", "--noinput", "--fake-initial"], "migration"
     )
@@ -143,7 +152,7 @@ def fixup():
         print(f"  - {job_2017}/")
         shutil.chown(job_2017, LAVA_SYS_USER, LAVA_SYS_USER)
 
-    # Fix devices, device-types and health-checks ownes/group
+    # Fix devices, device-types and health-checks owner/group
     for item in ["devices", "device-types", "health-checks"]:
         print(f"  - {DISPATCHER_CONFIG / item}/")
         shutil.chown(DISPATCHER_CONFIG / item, LAVA_SYS_USER, LAVA_SYS_USER)
@@ -306,7 +315,8 @@ DATABASES:
 
     if options.db:
         print("Create database:")
-        database(config)
+        create_database(config)
+        update_database()
 
 
 if __name__ == "__main__":
