@@ -104,7 +104,7 @@ def test_raise_exception():
     with pytest.raises(JobError) as exc:
         action.raise_exception("bug", "A strange error")
     assert exc.match(  # nosec - assert is ok
-        "Unknow exception 'bug' with 'A strange error'"
+        "Unknown exception 'bug' with 'A strange error'"
     )
 
 
@@ -518,6 +518,9 @@ def test_run_script_multinode(monkeypatch):
             self.captured.append(("sync", *args))
             return '{"response": "ack"}'
 
+        def set_timeout(self, duration):
+            pass
+
     monkeypatch.setattr(time, "time", Timing())
     action = TestInteractiveAction()
     action.multinode_proto = None
