@@ -1,3 +1,4 @@
+import subprocess
 import pytest
 from lava_dispatcher.utils.docker import DockerRun
 
@@ -8,7 +9,7 @@ def run():
 
 
 def test_basic(run):
-    assert run.cmdline() == ["docker", "run", "--rm", "foobar"]
+    assert run.cmdline() == ["docker", "run", "--rm", "--init", "foobar"]
 
 
 def test_name(run):
@@ -121,7 +122,9 @@ def test_run_architecture_check_success(mocker):
 
     docker = DockerRun("myimage")
     docker.run("echo")  # no crash = success
-    check_call.assert_called_with(["docker", "run", "--rm", "myimage", "echo"])
+    check_call.assert_called_with(
+        ["docker", "run", "--rm", "--init", "myimage", "echo"]
+    )
     getLogger.assert_not_called()
 
 
@@ -138,6 +141,50 @@ def test_run_with_action(mocker):
     action.run_cmd.assert_has_calls(
         [
             mocker.call(["docker", "pull", "myimage"]),
-            mocker.call(["docker", "run", "--rm", "myimage", "date"]),
+            mocker.call(["docker", "run", "--rm", "--init", "myimage", "date"]),
         ]
     )
+
+
+def test_run_with_local_image_does_not_pull(mocker):
+    mocker.patch("lava_dispatcher.utils.docker.DockerRun.__check_image_arch__")
+    docker = DockerRun("myimage")
+    docker.local(True)
+    action = mocker.MagicMock()
+    docker.run("date", action=action)
+    action.run_cmd.assert_has_calls(
+        [
+            mocker.call(["docker", "image", "inspect", mocker.ANY, "myimage"]),
+            mocker.call(["docker", "run", "--rm", "--init", "myimage", "date"]),
+        ]
+    )
+
+
+def test_from_parameters():
+    assert DockerRun.from_parameters({"image": "foo"}).image == "foo"
+    assert not DockerRun.from_parameters({"image": "foo"}).__local__
+    assert DockerRun.from_parameters({"image": "foo", "local": True}).__local__
+
+
+def test_wait(mocker):
+    docker = DockerRun("myimage")
+    docker.name("foobar")
+
+    sleep = mocker.patch("time.sleep")
+    inspect = mocker.patch(
+        "subprocess.check_call",
+        side_effect=[
+            subprocess.CalledProcessError(
+                1, ["docker", "inspect", "--format=.", "foobar"]
+            ),
+            None,
+        ],
+    )
+    docker.wait()
+    call = mocker.call(
+        ["docker", "inspect", mocker.ANY, "foobar"],
+        stdout=subprocess.DEVNULL,
+        stderr=subprocess.DEVNULL,
+    )
+    inspect.assert_has_calls([call, call])
+    sleep.assert_called_once()
