@@ -56,6 +56,9 @@ class TestBareboxTemplates(BaseTemplate.BaseTemplateCases):
     def test_imx6qp_wandboard_revd1_template(self):
         barebox_helper(self, "imx6qp-wandboard-revd1")
 
+    def test_imx8mq_zii_ultra_zest_template(self):
+        barebox_helper(self, "imx8mq-zii-ultra-zest")
+
     def test_dove_cubox_template(self):
         barebox_helper(self, "dove-cubox")
 
