@@ -127,7 +127,7 @@ class TestHealthCheckScheduling(TestCase):
         self.assertEqual(self.device02.get_health_check(), None)
         self.assertEqual(self.device03.get_health_check(), None)
         # Schedule without health check
-        available_devices = schedule_health_checks(logging.getLogger())[0]
+        available_devices = schedule_health_checks(logging.getLogger())
         self.assertEqual(available_devices, {"panda": ["panda01", "panda03"]})
 
     def test_disabled_hc(self):
@@ -139,7 +139,7 @@ class TestHealthCheckScheduling(TestCase):
 
         self.device_type01.disable_health_check = True
         self.device_type01.save()
-        available_devices = schedule_health_checks(logging.getLogger())[0]
+        available_devices = schedule_health_checks(logging.getLogger())
         self.assertEqual(available_devices, {"panda": ["panda01", "panda03"]})
 
     def test_no_devicedict(self):
@@ -166,7 +166,7 @@ class TestHealthCheckScheduling(TestCase):
         self.assertNotEqual(self.device02.get_health_check(), None)
         self.assertNotEqual(self.device03.get_health_check(), None)
 
-        available_devices = schedule_health_checks(logging.getLogger())[0]
+        available_devices = schedule_health_checks(logging.getLogger())
         self.assertEqual(available_devices, {"panda": []})
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
@@ -185,7 +185,7 @@ class TestHealthCheckScheduling(TestCase):
         self.device02.save()
         self.device03.health = Device.HEALTH_GOOD
         self.device03.save()
-        available_devices = schedule_health_checks(logging.getLogger())[0]
+        available_devices = schedule_health_checks(logging.getLogger())
         self.assertEqual(available_devices, {"panda": ["panda03"]})
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
@@ -204,7 +204,7 @@ class TestHealthCheckScheduling(TestCase):
         self.device02.save()
         self.device03.health = Device.HEALTH_LOOPING
         self.device03.save()
-        available_devices = schedule_health_checks(logging.getLogger())[0]
+        available_devices = schedule_health_checks(logging.getLogger())
         self.assertEqual(available_devices, {"panda": []})
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
@@ -229,7 +229,7 @@ class TestHealthCheckScheduling(TestCase):
             self.device02.save()
             self.device03.health = health
             self.device03.save()
-            available_devices = schedule_health_checks(logging.getLogger())[0]
+            available_devices = schedule_health_checks(logging.getLogger())
             self.assertEqual(available_devices, {"panda": []})
             self._check_hc_not_scheduled(self.device01)
             self._check_hc_not_scheduled(self.device02)
@@ -430,7 +430,7 @@ actions: []
         self.device_type01.disable_health_check = False
         self.device_type01.save()
 
-        schedule_health_checks(logging.getLogger())[0]
+        schedule_health_checks(logging.getLogger())
 
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
@@ -442,7 +442,7 @@ actions: []
         self.device_type01.disable_health_check = False
         self.device_type01.save()
 
-        schedule_health_checks(logging.getLogger())[0]
+        schedule_health_checks(logging.getLogger())
 
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
@@ -455,7 +455,7 @@ actions: []
         self.device_type01.disable_health_check = False
         self.device_type01.save()
 
-        schedule_health_checks(logging.getLogger())[0]
+        schedule_health_checks(logging.getLogger())
 
         self._check_hc_scheduled(self.device01)
         self._check_hc_not_scheduled(self.device02)
